# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4Browser.BrowserSettings as BrowserSettings
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from QT4Browser.FileBrowser import FileBrowser as FileBrowser
from typing import ClassVar, Set, Tuple

class FileSelect(PyQt5.QtWidgets.QDialog):
    _FileSelect__contextFileMap: ClassVar[dict] = ...
    def __init__(self, *pargs, **kargs) -> None: ...
    def _FileSelect__connect(self): ...
    def _FileSelect__doApply(self, selection): ...
    def _FileSelect__doDefault(self): ...
    def _FileSelect__setup_children(self): ...
    def _FileSelect__setup_layout(self): ...
    def bringTabToFront(self, tabName): ...
    def currentLocation(self): ...
    def done(self, code): ...
    def getFileBrowser(self): ...
    def hideEvent(self, event): ...
    def loadSettings(self): ...
    def saveSettings(self): ...
    def setCurrentLocation(self, location): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Nodes3DAPI.AbstractTransform as AT
import PyFnAttribute as FnAttribute
import PyFnGeolibServices as FnGeolibServices
import Nodes3DAPI.Node3D as Node3D
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI.TransformUtil as TransformUtil
import typing
from Nodes3DAPI.AbstractTransform import AbstractTransform
from Nodes3DAPI_cmodule import BuildGroupAttrFromParam as BuildGroupAttrFromParam
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

_ExtraHints: dict
_Parameter_XML: str
_interactiveXformText: str

class CameraNode3D(AbstractTransform):
    _CameraNode3D__passThroughExcludes: ClassVar[set] = ...
    def __init__(self) -> None: ...
    def _CameraNode3D__paramToTimeSampledDoubleAttr(self, param, frameTime, graphState: typing.Optional[NodegraphAPI.GraphState] = ...): ...
    def _getOpChain(self, interface): ...
    def addParameterHints(self, attrName, inputDict): ...
    def canOverride(self, attrName): ...
    def findOverrideParameter(self, path, attrName, time, index: Incomplete | None = ..., editable: bool = ..., **kwargs): ...
    def getCameraAttributes(self, cameraName, frameTime, graphState: typing.Optional[NodegraphAPI.GraphState] = ...): ...
    def getCameraGeometry(self, cameraName, frameTime, graphState: typing.Optional[NodegraphAPI.GraphState] = ...): ...
    def getDefaultObjectName(self): ...
    def getExtraParameters(self): ...
    def getObjectType(self): ...
    def getRootAttr(self, objScenegraphLocation): ...
    def getScenegraphLocation(self): ...
    def getWorldAttr(self, objScenegraphLocation, frameTime: Incomplete | None = ...): ...
    def setOverride(self, path, attrName, time, attrData, index: Incomplete | None = ..., **kwargs): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
from UI4.Tabs.NodeGraphTab.Layers.MenuLayer import MenuLayer as MenuLayer
from _typeshed import Incomplete
from typing import Set, Tuple

g_chosenValue: None

class BookmarkJumpMenuLayer(MenuLayer):
    def __init__(self, name: Incomplete | None = ..., visible: bool = ..., interactive: bool = ..., enabled: bool = ...) -> None: ...
    def getBottomText(self): ...
    def getChosenValue(self): ...
    def getEntries(self): ...
    def onEntryChosen(self, value): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import UI4.FormMaster.EnableableParameterPolicy as EnableableParameterPolicy
import UI4.FormMaster.HintsDelegate as HintsDelegate
import UI4.FormMaster.ParameterPolicy as ParameterPolicy
from UI4.FormMaster.NodeHints.Common2D import GetBoundsParamDict as GetBoundsParamDict
from typing import Set, Tuple

DEEPSHAD_EXTENSIONS: str
_NodeHints: dict



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import DrawingModule as DrawingModule
import KatanaResources as KatanaResources
import NodegraphAPI as NodegraphAPI
import UI4.KatanaPrefs.PrefNames as PrefNames
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
from UI4.KatanaPrefs.KatanaPrefsObject import KatanaPrefs as KatanaPrefs
from UI4.Tabs.NodeGraphTab.Layers.TransientLayer import TransientLayer as TransientLayer
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class LinkConnectionLayer(TransientLayer):
    _LinkConnectionLayer__pixmaps: ClassVar[dict] = ...
    def __init__(self, basePorts, savedLinks, disableScenegraphUpdates: bool = ..., *args, **kwargs) -> None: ...
    def _LinkConnectionLayer__connectLinks(self, targetPort): ...
    def _LinkConnectionLayer__create_dot_node(self): ...
    def _LinkConnectionLayer__dropLinks(self): ...
    def _LinkConnectionLayer__exitNoChange(self): ...
    def _LinkConnectionLayer__getConsumerHitPort(self, node: NodegraphAPI.Node, basePorts): ...
    def _LinkConnectionLayer__getHitPort(self, node: NodegraphAPI.Node, currentPort): ...
    def _LinkConnectionLayer__getPortDescription(self, port: NodegraphAPI.Port, isSendOrReturnPort: Incomplete | None = ...) -> PortDescription: ...
    def _LinkConnectionLayer__isConnectionViable(self, portA: NodegraphAPI.Port | None, portB: NodegraphAPI.Port | None) -> bool: ...
    def _LinkConnectionLayer__isSendOrReturnPort(self, port: NodegraphAPI.Port) -> bool: ...
    def _LinkConnectionLayer__multiOutPopupCallback(self, port: NodegraphAPI.Port): ...
    def _LinkConnectionLayer__nodeDeleteHandler(self, eventType, eventID, node: NodegraphAPI.Node, *args, **kwargs): ...
    def _LinkConnectionLayer__processKeyPress(self, event): ...
    def _LinkConnectionLayer__processMouseMove(self, event): ...
    def _LinkConnectionLayer__processMousePress(self, event): ...
    def getBasePorts(self) -> list[NodegraphAPI.Port]: ...
    def paintGL(self): ...
    def processEvent(self, event): ...
    def processMousePress(self, event): ...
    def __del__(self) -> None: ...

class PortDescription(tuple):
    _field_defaults: ClassVar[dict] = ...
    _fields: ClassVar[tuple] = ...
    _fields_defaults: ClassVar[dict] = ...
    def __init__(self, _cls, node: NodegraphAPI.Node, type, name, isSendOrReturnPort) -> None: ...
    def _asdict(self): ...
    @classmethod
    def _make(cls, iterable): ...
    def _replace(self, _self, **kwds): ...
    def __getnewargs__(self): ...
    @property
    def isSendOrReturnPort(self): ...
    @property
    def name(self): ...
    @property
    def node(self): ...
    @property
    def type(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import QT4GLLayerStack as QT4GLLayerStack
import QT4GLLayerStack.LayerStack
from typing import Set, Tuple

class HistogramLayer(QT4GLLayerStack.LayerStack.Layer):
    def __init__(self, *args, **kwargs) -> None: ...
    def drawHistogram(self): ...
    def getHistogram(self): ...
    def isChannelEnabled(self, channel): ...
    def paintGL(self): ...
    def setChannels(self, channels): ...
    def setHistogram(self, histogram): ...
    def setScale(self, scale): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyImath
import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4Color as QT4Color
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import UI4.Widgets.SortablePanel as SortablePanel
import UI4 as UI4
import UI4.Widgets.SortablePanel
import Utils as Utils
from PyUtilModule.VirtualKatana import ColorPaletteManager as ColorPaletteManager, Widgets as Widgets
from UI4.Tabs.BaseTab import BaseTab as BaseTab
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

PluginRegistry: list

class ColorMathArea(PyQt5.QtWidgets.QWidget):
    def __init__(self, parent) -> None: ...
    def _ColorMathArea__update(self, *args, **kwargs): ...
    def setGlobals(self, globalsDict): ...

class ColorPaletteEditor(UI4.Widgets.SortablePanel.SortablePanelFormWidget):
    globalsChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent, policy, factory) -> None: ...
    def _ColorPaletteEditor__rebuildAllCB(self, args): ...
    def _ColorPaletteEditor__setupEventHandlers(self, enabled): ...
    def _freeze(self): ...
    def _thaw(self): ...
    def addColor(self): ...
    def buildAddMenu(self, menu): ...
    def clearAll(self): ...
    def dragEnterEvent(self, event): ...
    def dropEvent(self, event): ...
    def emit_globalsChanged(self, *args, **kwargs): ...
    def getGlobals(self): ...
    def panelDeleted(self, index): ...
    def panelReordered(self, oldPos, newPos): ...
    def updatePanels(self): ...

class ColorPalettePanel(BaseTab):
    def __init__(self, parent) -> None: ...
    def _ColorPalettePanel__colorPalette_globalsChanged_CB(self): ...
    def _ColorPalettePanel__createColorPalette(self, index: Incomplete | None = ...): ...
    def _ColorPalettePanel__recreatePolicy(self, args): ...

class CustomVector(PyImath.V3d):
    def __add__(self, other): ...
    def __mul__(self, other): ...
    def __sub__(self, other): ...
    def __truediv__(self, other): ...

class InputPanel(UI4.Widgets.SortablePanel.SortablePanelBase):
    def __init__(self, parent, name, policy, factory, callbackfcn) -> None: ...
    def adopt(self, layer): ...
    def getWidget(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import PyXmlIO as PyXmlIO
import QT4FormWidgets as QT4FormWidgets
import QT4FormWidgets.InputWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import UI4.Widgets.SortablePanel
import Utils as Utils
from QT4FormWidgets.PopupFormWidget import PopupFormWidget
from QT4FormWidgets.StringFormWidget import StringFormWidget
from UI4.Widgets.SortablePanel import ParameterSortablePanel as ParameterSortablePanel, ParameterSortablePanelFormWidget as ParameterSortablePanelFormWidget, SortablePanelBase as SortablePanelBase
from typing import Set, Tuple

class FileOutFormatFormWidget(PopupFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...

class FileOutInputsEditor(UI4.Widgets.SortablePanel.ParameterSortablePanelFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _FileOutInputsEditor__actionMenuCB(self, menu): ...
    def _FileOutInputsEditor__addInputCB(self): ...
    def _FileOutInputsEditor__portsUpdate(self): ...
    def _FileOutInputsEditor__portsUpdateCB(self, args): ...
    def _FileOutInputsEditor__postCreateAssets(self, versionUp: bool = ...): ...
    def _FileOutInputsEditor__postCreateAssetsVersionUp(self): ...
    def _FileOutInputsEditor__preCreateAssets(self, versionUp: bool = ...): ...
    def _FileOutInputsEditor__preCreateAssetsVersionUp(self): ...
    def _FileOutInputsEditor__renumberPanels(self): ...
    def _FileOutInputsEditor__setupEventHandlers(self, enabled): ...
    def _freeze(self): ...
    def _getPanelForPolicy(self, vp): ...
    def _thaw(self): ...
    def buildAddMenu(self, menu): ...
    def panelDeleted(self, index): ...
    def panelReordered(self, oldPos, newPos): ...
    def updatePanels(self): ...

class FileOutPostScriptsEditor(UI4.Widgets.SortablePanel.ParameterSortablePanelFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _FileOutPostScriptsEditor__portsUpdate(self): ...
    def _FileOutPostScriptsEditor__portsUpdateCB(self, args): ...
    def _FileOutPostScriptsEditor__renumberPanels(self): ...
    def _FileOutPostScriptsEditor__setupEventHandlers(self, enabled): ...
    def _freeze(self): ...
    def _getPanelForPolicy(self, vp): ...
    def _thaw(self): ...
    def addPostScript(self): ...
    def buildAddMenu(self, menu): ...
    def panelDeleted(self, index): ...
    def panelReordered(self, oldPos, newPos): ...
    def updatePanels(self): ...

class FileOutRepPrefixFormWidget(StringFormWidget):
    def __init__(self, *args) -> None: ...
    def _checkControlWidget(self): ...
    def setIndex(self, index): ...

class FileOutRepPrefixHelp(QT4FormWidgets.InputWidgets.HelpFWidget):
    def __init__(self, *args) -> None: ...
    def getHelpText(self): ...
    def getHelpType(self): ...
    def isHelpEnabled(self): ...
    def setIndex(self, index): ...

class InputPanel(UI4.Widgets.SortablePanel.ParameterSortablePanel):
    def __init__(self, parent, name, policy, factory) -> None: ...
    def _InputPanel__copyExpression(self): ...
    def setIndex(self, index): ...

class PostScriptPanel(UI4.Widgets.SortablePanel.ParameterSortablePanel):
    def __init__(self, parent, name, policy, factory) -> None: ...
    def setIndex(self, index): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

class WeakMethodBound:
    def __init__(self, f) -> None: ...
    def __bool__(self) -> bool: ...
    def __call__(self, *args, **kwargs): ...
    def __eq__(self, other) -> bool: ...
    def __hash__(self) -> int: ...

class WeakMethodFree:
    def __init__(self, f) -> None: ...
    def __bool__(self) -> bool: ...
    def __call__(self, *args, **kwargs): ...
    def __eq__(self, other) -> bool: ...
    def __hash__(self) -> int: ...

class WeakMethodIsDeadError(TypeError): ...

def WeakMethod(f): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import Utils as Utils
from _typeshed import Incomplete
from typing import Set, Tuple

def CalculateInOut(node: Nodes2DAPI.Node2D): ...
def GetChannelNames(node: NodegraphAPI.Node, time: Incomplete | None = ...): ...
def GetDiskFrameRange(fileName, diskOnly: bool = ...): ...
def GetFileInSequence(node: NodegraphAPI.Node, time: Incomplete | None = ...): ...
def ResetToDefaultChannelMapping(node: NodegraphAPI.Node): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import KatanaResources as KatanaResources
import Nodes3DAPI as Nodes3DAPI
import UI4.KatanaPrefs.PrefNames as PrefNames
import PyQt5.QtCore
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import Nodes3DAPI.ScenegraphManager as ScenegraphManager
import UI4 as UI4
from PyUtilModule.ScenegraphUtils import AbbreviateScenegraphLocations as AbbreviateScenegraphLocations
from QT4Widgets.FilterablePopupButton import FilterablePopupButton as FilterablePopupButton
from UI4.Widgets.SceneGraphView.SceneGraphView import SceneGraphView
from typing import ClassVar, Set, Tuple

class SceneGraphFindButton(FilterablePopupButton):
    _SceneGraphFindButton__SelectAllButtonText: ClassVar[str] = ...
    def __init__(self, parent, sceneGraphView) -> None: ...
    def _SceneGraphFindButton__getFilteredLocationPaths(self, locationFilter: str) -> list[str]: ...
    def _SceneGraphFindButton__getSelectedLocations(self): ...
    def _SceneGraphFindButton__getVisibleCameraLocations(self): ...
    def _SceneGraphFindButton__getVisibleLightLocations(self): ...
    def _SceneGraphFindButton__getVisibleLocations(self): ...
    def _SceneGraphFindButton__on_aboutToShow(self, *args): ...
    def _SceneGraphFindButton__on_itemChosen(self, nodeName, meta): ...
    def _SceneGraphFindButton__scrollToLocation(self, locationPath): ...
    def _SceneGraphFindButton__selectAllClicked(self): ...
    def _SceneGraphFindButton__setSelectButtonState(self, addToSelection: bool = ...): ...
    def _getAttribute(self, locationPath, attributeName): ...
    def enterEvent(self, event: PyQt5.QtCore.QEvent): ...
    def getSceneGraphView(self) -> SceneGraphView: ...
    def leaveEvent(self, event: PyQt5.QtCore.QEvent): ...
    def setLocationFilter(self, locationFilter: str): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.App.KeyboardShortcutManager as KeyboardShortcutManager
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from UI4.Tabs.BaseTab import BaseTab as BaseTab
from _typeshed import Incomplete
from typing import Set, Tuple

PluginRegistry: list

class KeyboardShortcutsTab(BaseTab):
    def __init__(self, parent) -> None: ...

class KeyboardShortcutsTreeView(PyQt5.QtWidgets.QTreeView):
    def __init__(self, model, parent: Incomplete | None = ...) -> None: ...
    def contextMenuEvent(self, contextMenuEvent: PyQt5.QtGui.QContextMenuEvent): ...
    def expanded(self): ...
    def on_model_dataChanged(self, topLeftIndex, bottomRightIndex): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtWidgets
import PyQt5.QtWidgets as QtWidgets
from typing import Set, Tuple

class Checkbox(PyQt5.QtWidgets.QCheckBox):
    def hitButton(self, pos: PyQt5.QtCore.QPoint) -> bool: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets as QT4FormWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4.Widgets as Widgets
from QT4FormWidgets.FormWidget import FormWidget
from typing import ClassVar, Set, Tuple

class DeferredGroupTreeFormWidget(FormWidget):
    NAMECOLUMN: ClassVar[int] = ...
    STATECOLUMN: ClassVar[int] = ...
    VALUECOLUMN: ClassVar[int] = ...
    def __init__(self, parent, policy, factory) -> None: ...
    def _DeferredGroupTreeFormWidget__addExpandedDescendentsToStash(self, item): ...
    def _DeferredGroupTreeFormWidget__addPolicyChildren(self, policy, parentItem): ...
    def _DeferredGroupTreeFormWidget__filterUpdate(self, filterText): ...
    def _DeferredGroupTreeFormWidget__refresh(self): ...
    def _DeferredGroupTreeFormWidget__treeAboutToDrag(self, dragItems, dragObject): ...
    def _DeferredGroupTreeFormWidget__treeContextMenuEvent(self, event): ...
    def _DeferredGroupTreeFormWidget__treeItemCollapsed(self, item): ...
    def _DeferredGroupTreeFormWidget__treeItemExpanded(self, item): ...
    def _DeferredGroupTreeFormWidget__treeKeyPressEvent(self, event): ...
    def _DeferredGroupTreeFormWidget__treeMousePressEvent(self, event): ...
    def _buildControlWidget(self, layout): ...
    def _buildLabel(self, labelText, pos: int = ...): ...
    def _thaw(self): ...
    def on_copyAction_triggered(self): ...
    def showPopdown(self, value): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import FCurveListView as FCurveListView, FCurveSnapSettingsMenu as FCurveSnapSettingsMenu, FCurveValueEdit as FCurveValueEdit, MixedGroupState as MixedGroupState, UniqueListDict as UniqueListDict
from QTFCurve.FCurveGraphValueListWidget import FCurveGraphValueListWidget as FCurveGraphValueListWidget
from typing import Set, Tuple



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
from _typeshed import Incomplete
from typing import Set, Tuple

def ContainerHintDictFromAttr(attr, path: str = ..., output: Incomplete | None = ..., allowGroupAttrForm: bool = ...): ...
def FlushCache(): ...
def HintDictFromAttr(attr, allowGroupAttrForm: bool = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Nodes2DAPI as Nodes2DAPI
import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
from QT4FormWidgets.BaseValueFormWidget import BaseValueFormWidget
from QT4FormWidgets.CapsuleFormWidget import CapsuleFormWidget
from typing import ClassVar, Set, Tuple

class ClickingHBox(PyQt5.QtWidgets.QFrame):
    _ClickingHBox__FRAME_WIDTH: ClassVar[int] = ...
    pressed: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent) -> None: ...
    def eventFilter(self, object, event): ...
    def mousePressEvent(self, ev): ...
    def setPressed(self, pressed): ...
    def setText(self, text): ...

class ViewSelectCapsuleFormWidget(CapsuleFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...

class ViewSelectPopupFormWidget(BaseValueFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _ViewSelectPopupFormWidget__activeViewsButtonPressed(self): ...
    def _ViewSelectPopupFormWidget__updateActiveViews(self): ...
    def _ViewSelectPopupFormWidget__viewCheckboxPopupClosed(self): ...
    def _buildControlWidget(self, layout): ...
    def valueChangedEvent(self, event): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
from typing import ClassVar, Set, Tuple

class FileSaveDialog(PyQt5.QtWidgets.QDialog):
    def __init__(self, parent, options: dict = ...) -> None: ...
    def _FileSaveDialog__updateState(self): ...
    def _FileSaveDialog__validityChangeCallback(self, state): ...
    def getResult(self): ...

class FileSaveWidget(PyQt5.QtWidgets.QWidget):
    fileTextChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    validityChange: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent, options: dict = ...) -> None: ...
    def _FileSaveWidget__browseCallback(self): ...
    def _FileSaveWidget__fileTextChanged(self, text): ...
    def _FileSaveWidget__setValid(self, valid): ...
    def getActionMenu(self): ...
    def getResult(self): ...
    def isValid(self): ...
    def setLocation(self, loc): ...

class ProductOrFileSaveDialog(PyQt5.QtWidgets.QDialog):
    def __init__(self, parent, options: dict = ...) -> None: ...
    def _ProductOrFileSaveDialog__fileToggleCallback(self): ...
    def _ProductOrFileSaveDialog__productToggleCallback(self): ...
    def _ProductOrFileSaveDialog__updateState(self): ...
    def _ProductOrFileSaveDialog__validityChangeCallback(self, state): ...
    def addAdditionalWidgets(self, layout): ...
    def addButtonsToLayout(self): ...
    def getProductSaveWidget(self): ...
    def getResult(self): ...
    def isValid(self): ...
    def validityChange(self): ...

class ProductSaveDialog(PyQt5.QtWidgets.QDialog):
    def __init__(self, parent, options: dict = ...) -> None: ...
    def _ProductSaveDialog__updateState(self): ...
    def _ProductSaveDialog__validityChangeCallback(self, state): ...
    def addAdditionalWidgets(self, layout): ...
    def getResult(self): ...
    def isValid(self): ...
    def validityChange(self): ...

class _ClickableHBox(PyQt5.QtWidgets.QFrame):
    clicked: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent) -> None: ...
    def mousePressEvent(self, e): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute
from typing import Set, Tuple, overload

class AttributeSet:
    def __init__(self) -> None: ...
    def addSubOp(self, opType: str, opArgs: PyFnAttribute.GroupAttribute, batch: str = ...) -> None: ...
    def build(self) -> PyFnAttribute.GroupAttribute: ...
    def deleteAttr(self, attrName: str, batch: str = ...) -> None: ...
    def setAttr(self, attrName: str, attr: PyFnAttribute.Attribute, batch: str = ..., inherit: bool = ...) -> None: ...
    @overload
    def setCEL(self, cel: PyFnAttribute.StringAttribute, batch: str = ...) -> None: ...
    @overload
    def setCEL(self, cels: list[str], batch: str = ...) -> None: ...
    @overload
    def setLocationPaths(self, locationPath: PyFnAttribute.StringAttribute, batch: str = ...) -> None: ...
    @overload
    def setLocationPaths(self, locationPaths: list[str], batch: str = ...) -> None: ...

class StaticSceneCreate:
    def __init__(self, pathsAreAbsolute: bool = ...) -> None: ...
    def addSubOpAtLocation(self, locationPath: str, opType: str, opArgs: PyFnAttribute.GroupAttribute) -> None: ...
    def build(self) -> PyFnAttribute.GroupAttribute: ...
    def createEmptyLocation(self, locationPath: str, locationType: str = ...) -> None: ...
    def setAttrAtLocation(self, locationPath: str, attrName: str, attr: PyFnAttribute.Attribute) -> None: ...
    def setAttrsAtLeafStateForLocation(self, locationPath: str, state: bool) -> None: ...
    def skipLocalActionsIfInputExistsAtLocation(self, locationPath: str, state: bool) -> None: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import AssetBrowser as AssetBrowser
import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
from QT4FormWidgets.HintUtils import HintTrue as HintTrue
from typing import ClassVar, Set, Tuple

class BaseAssetControlWidget(PyQt5.QtWidgets.QWidget):
    valueChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent, hints) -> None: ...
    def buildWidgets(self, hints): ...
    def emitValueChanged(self): ...
    def getValue(self): ...
    def setReadOnly(self, readOnly): ...
    def setValue(self, value): ...

class BaseAssetRenderWidget(PyQt5.QtWidgets.QWidget):
    def __init__(self, parent, hints, outputInfo) -> None: ...
    def buildWidgets(self, hints): ...
    def getOutputInfo(self): ...
    def updateWidgets(self): ...

class BaseAssetWidgetDelegate(PyQt5.QtCore.QObject):
    def __init__(self, valuePolicy, *args) -> None: ...
    def addAssetFormWidgetMenuItems(self, menu): ...
    def configureAssetBrowser(self, browser): ...
    def createAssetControlWidget(self, parent): ...
    def createAssetRenderWidget(self, parent, outputInfo): ...
    def getQuickLinkPathsForContext(self, context): ...
    def getValuePolicy(self): ...
    def getWidgetHints(self): ...
    def shouldAddFileTabToAssetBrowser(self): ...
    def shouldAddStandardMenuItems(self): ...

class DefaultAssetControlWidget(BaseAssetControlWidget):
    def _DefaultAssetControlWidget__lostFocus(self): ...
    def buildWidgets(self, hints): ...
    def getValue(self): ...
    def setPalette(self, palette): ...
    def setReadOnly(self, readOnly): ...
    def setValue(self, value): ...

class DefaultAssetRenderWidget(BaseAssetRenderWidget):
    def buildWidgets(self, hints): ...
    def updateWidgets(self): ...

class DefaultAssetWidgetDelegate(BaseAssetWidgetDelegate):
    def createAssetControlWidget(self, parent): ...
    def createAssetRenderWidget(self, parent, outputInfo): ...

def GetAssetWidgetDelegate(assetSystemName, valuePolicy): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4GLLayerStack.LayerStack as LayerStack
import QT4GLLayerStack.LayerStack
from typing import Set, Tuple

class CheckerboardLayer(QT4GLLayerStack.LayerStack.Layer):
    def __init__(self, *args, **kwargs) -> None: ...
    def _CheckerboardLayer__buildDisplayList(self, width, height): ...
    def paintGL(self): ...
    def resizeGL(self): ...
    def setVisible(self, visible): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from QT4Panels.Edge import Edge
from typing import Set, Tuple

OtherSide: tuple
SIDEB: int
SIDEL: int
SIDER: int
SIDET: int
SignEdge: tuple

class Edge:
    def __init__(self, start, end, position, vertical) -> None: ...
    def copy(self): ...
    def distance(self, x, y): ...
    def intersect(self, other): ...
    def __eq__(self, other) -> bool: ...
    def __hash__(self) -> int: ...
    def __lt__(self, other) -> bool: ...

class EdgeWithInfo(Edge):
    def __init__(self, edge, frames) -> None: ...
    def getDragPosition(self): ...
    def getNeighbors(self, sign): ...
    def minSize(self, other): ...
    def setDragPosition(self, position): ...
    def stripFrame(self, frame): ...

def AdjustChains(chains, side): ...
def BuildDragChains(x, y, fullEdge, frames): ...
def ClosestEdge(x, y, vertical, expand, frames): ...
def ClosestHoverEdge(x, y, dist, rect): ...
def ContainsPoint(rect, x, y): ...
def DragChains(x, y, chains): ...
def FindChains(edge, frames, side): ...
def IsNearEdges(x, y, frames): ...
def JoinEdges(frame, edge1, edge2): ...
def LargestColinearEdge(edge, regions, side): ...
def MinimumMatchingEdge(frame, side, frames): ...
def NewBorderRect(scale, side): ...
def RectEdge(coordinates, side): ...
def SplitRect(origRect, side): ...
def SplitTargetRect(rect): ...
def SquashRect(rect, scale, side): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import ConditionalStateGrammar as ConditionalStateGrammar
from ConditionalStateGrammar.Parser import ParseCSG as ParseCSG
from typing import Set, Tuple

_ExtraHints: dict
_Parameter_XML: str



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

NoVersion: tuple

def GetCurrentVersion(): ...
def GetNodegraphVersion(xmlString): ...
def GetVersionKey(version): ...
def VersionCmp(a, b): ...
def tupleToVersion(versionTuple): ...
def versionToTuple(versionTag): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import logging
from UI4.Util.Record import Record as Record
from typing import Set, Tuple

ICON_PREFIX: str
LEVEL_NAMES: dict

class LogRecord(Record):
    def __init__(self, index: int, logRecord: logging.LogRecord) -> None: ...
    @staticmethod
    def getLevelIconName(level: int, bigger: bool = ..., highlight: bool = ...) -> str: ...
    def getLogRecord(self): ...
    def getLogRecordName(self) -> str: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
from _typeshed import Incomplete
from typing import Set, Tuple

class AbstractSyntaxHighlighter(PyQt5.QtGui.QSyntaxHighlighter):
    def __init__(self, document: PyQt5.QtWidgets.QTextEdit | PyQt5.QtGui.QTextDocument | PyQt5.QtCore.QObject, baseFormat: PyQt5.QtGui.QTextCharFormat, specialWords: Incomplete | None = ...) -> None: ...
    def _AbstractSyntaxHighlighter__configureHighlighter(self): ...
    def _createCustomBlocks(self): ...
    def _createFormat(self, color: str = ..., backgroundColor: str = ..., underlineColor: str = ..., style: str = ...) -> PyQt5.QtGui.QTextCharFormat: ...
    def _createFormats(self) -> dict[str, PyQt5.QtGui.QTextCharFormat]: ...
    def _createPostBlockRules(self): ...
    def _createRules(self): ...
    def _getBaseFormat(self) -> PyQt5.QtGui.QTextCharFormat: ...
    def highlightBlock(self, text: str): ...
    def setTrailingWhitespaceHighlighted(self, trailingWhitespaceHighlighted: bool): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyOpenColorIO as OCIO
import PyQt5.QtCore
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class _GlobalColorPolicy(PyQt5.QtCore.QObject):
    displayChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self) -> None: ...
    def _GlobalColorPolicy__rebuildProcessor(self): ...
    def getDisplay(self): ...
    def getDisplayColorSpaceName(self): ...
    def getNoFilmlookColorSpaceName(self): ...
    def getNoFilmlookProcessor(self): ...
    def getProcessor(self): ...
    def setDisplay(self, display): ...

def ApplyFilmlook(color, processor: Incomplete | None = ...): ...
def GetErrorMessageForColor(color, checkAlpha: bool = ...): ...
def GetGlobalColorPolicy(): ...
def GetGlobalDisplay(): ...
def Get_UseFixedSatHSV(): ...
def Get_UseSingleComponentRGB(): ...
def SetGlobalDisplay(display): ...
def Set_UseFixedSatHSV(value): ...
def Set_UseSingleComponentRGB(value): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.FormMaster.EnableableParameterPolicy as EnableableParameterPolicy
import UI4.FormMaster.HintsDelegate as HintsDelegate
import UI4.FormMaster.ParameterPolicy as ParameterPolicy
from UI4.FormMaster.NodeHints.Common2D import GetAngleNumberDict as GetAngleNumberDict, GetAspectRatioNumberDict as GetAspectRatioNumberDict, GetCapsuleRgbaDict as GetCapsuleRgbaDict, GetPolygonSidesDict as GetPolygonSidesDict, GetPositivePixelNumberDict as GetPositivePixelNumberDict
from typing import Set, Tuple

BloomAmountParamHints: dict
BloomEnableParamHints: dict
BloomGroupParamHints: dict
BloomModeParamHints: dict
BloomThresholdParamHints: dict
BorderExtendParamHints: dict
BorderOverscanParamHints: dict
_NodeHints: dict
_NodeName: str



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Util.IconManager as IconManager
import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
from QT4FormWidgets.FormWidget import FormWidget
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class ScriptButtonFormWidget(FormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _ScriptButtonFormWidget__clicked(self): ...
    def _buildControlWidget(self, layout): ...
    def _thaw(self): ...
    def contextMenuEvent(self, event): ...
    def setLabelWidth(self, width): ...

class ScriptToolbarFormWidget(FormWidget):
    class _ToolbarButton(PyQt5.QtWidgets.QPushButton):
        runscript: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
        def __init__(self, parent, name: str = ..., iconPath: Incomplete | None = ..., scriptText: Incomplete | None = ..., flat: bool = ...) -> None: ...
        def _ToolbarButton__clicked(self): ...
    def __init__(self, parent, policy, factory) -> None: ...
    def _ScriptToolbarFormWidget__runScript(self, button, scriptText): ...
    def _buildControlWidget(self, layout): ...
    def contextMenuEvent(self, event): ...
    def setLabelWidth(self, width): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Utils.EventModule as EventModule
import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import Utils.UndoStack as UndoStack
import Utils as Utils
import Utils.UndoStack
from _typeshed import Incomplete
from typing import Set, Tuple

_parameter_changing_map: dict

class _FloatVectorStateAtTime:
    def __init__(self, parameter, time) -> None: ...

class node_addInputPort_UndoEntry(Utils.UndoStack.UndoEntry):
    def __init__(self, nodeName, portName, portIndex) -> None: ...
    def getName(self): ...
    def redo(self): ...
    def undo(self): ...

class node_addOutputPort_UndoEntry(Utils.UndoStack.UndoEntry):
    def __init__(self, nodeName, portName, portIndex) -> None: ...
    def getName(self): ...
    def redo(self): ...
    def undo(self): ...

class node_create_UndoEntry(Utils.UndoStack.UndoEntry):
    def __init__(self, nodeName, nodeType) -> None: ...
    def getName(self): ...
    def redo(self): ...
    def undo(self): ...

class node_delete_UndoEntry(Utils.UndoStack.UndoEntry):
    def __init__(self, nodeName, nodeParentName, xmlElement, locked) -> None: ...
    def getName(self): ...
    def redo(self): ...
    def undo(self): ...

class node_paste_UndoEntry(Utils.UndoStack.UndoEntry):
    def __init__(self, nodeNames, nodeParentName, xmlElement) -> None: ...
    def redo(self): ...
    def undo(self): ...

class node_removeInputPort_UndoEntry(Utils.UndoStack.UndoEntry):
    def __init__(self, nodeName, portName, portIndex, portMetadata, portTags) -> None: ...
    def getName(self): ...
    def redo(self): ...
    def undo(self): ...

class node_removeOutputPort_UndoEntry(Utils.UndoStack.UndoEntry):
    def __init__(self, nodeName, portName, portIndex, portMetadata, portTags) -> None: ...
    def getName(self): ...
    def redo(self): ...
    def undo(self): ...

class node_renameInputPort_UndoEntry(Utils.UndoStack.UndoEntry):
    def __init__(self, nodeName, oldPortName, newPortName) -> None: ...
    def getName(self): ...
    def redo(self): ...
    def undo(self): ...

class node_renameOutputPort_UndoEntry(Utils.UndoStack.UndoEntry):
    def __init__(self, nodeName, oldPortName, newPortName) -> None: ...
    def getName(self): ...
    def redo(self): ...
    def undo(self): ...

class node_setAutoRenameAllowed_UndoEntry(Utils.UndoStack.UndoEntry):
    def __init__(self, nodeName, value) -> None: ...
    def getName(self): ...
    def redo(self): ...
    def undo(self): ...

class node_setBypassRouting_UndoEntry(Utils.UndoStack.UndoEntry):
    def __init__(self, nodeName, oldVal, newVal) -> None: ...
    def getName(self): ...
    def redo(self): ...
    def undo(self): ...

class node_setBypassed_UndoEntry(Utils.UndoStack.UndoEntry):
    def __init__(self, nodeName, bypassValue) -> None: ...
    def getName(self): ...
    def redo(self): ...
    def undo(self): ...

class node_setName_UndoEntry(Utils.UndoStack.UndoEntry):
    def __init__(self, undoName, redoName) -> None: ...
    def getName(self): ...
    def redo(self): ...
    def undo(self): ...

class node_setParent_UndoEntry(Utils.UndoStack.UndoEntry):
    def __init__(self, nodeName, undoParentName, redoParentName) -> None: ...
    def getName(self): ...
    def redo(self): ...
    def undo(self): ...

class node_setPosition_UndoEntry(Utils.UndoStack.UndoEntry):
    def __init__(self, nodeName, oldPosition, newPosition) -> None: ...
    def getName(self): ...
    def redo(self): ...
    def undo(self): ...

class node_setThumbnailEnabled_UndoEntry(Utils.UndoStack.UndoEntry):
    def __init__(self, nodeName, newValue, oldValue) -> None: ...
    def getName(self): ...
    def redo(self): ...
    def undo(self): ...

class node_setType_UndoEntry(Utils.UndoStack.UndoEntry):
    def __init__(self, nodeName, oldType, newType) -> None: ...
    def getName(self): ...
    def redo(self): ...
    def undo(self): ...

class node_shapeAttrsChanged_UndoEntry(Utils.UndoStack.UndoEntry):
    def __init__(self, nodeName, oldAttrs, newAttrs) -> None: ...
    def _node_shapeAttrsChanged_UndoEntry__setAttrs(self, attrs, otherAttrs): ...
    def getName(self): ...
    def redo(self): ...
    def undo(self): ...

class parameter_createChild_UndoEntry(Utils.UndoStack.UndoEntry):
    def __init__(self, parameterFullName, element, index) -> None: ...
    def getName(self): ...
    def redo(self): ...
    def undo(self): ...

class parameter_deleteChild_UndoEntry(Utils.UndoStack.UndoEntry):
    def __init__(self, parameterFullName, element, childName, index) -> None: ...
    def getName(self): ...
    def redo(self): ...
    def undo(self): ...

class parameter_floatVector_setValue_UndoEntry(Utils.UndoStack.UndoEntry):
    def __init__(self, parameterFullName, undoState, redoState) -> None: ...
    def _parameter_floatVector_setValue_UndoEntry__applyState(self, state): ...
    def getName(self): ...
    def redo(self): ...
    def undo(self): ...

class parameter_reorderChild_UndoEntry(Utils.UndoStack.UndoEntry):
    def __init__(self, parameterFullName, oldIndex, newIndex) -> None: ...
    def getName(self): ...
    def redo(self): ...
    def undo(self): ...

class parameter_reorderChildren_UndoEntry(Utils.UndoStack.UndoEntry):
    def __init__(self, parameterFullName, oldIndex, newIndex, count) -> None: ...
    def getName(self): ...
    def redo(self): ...
    def undo(self): ...

class parameter_reparentAtomic_UndoEntry(Utils.UndoStack.UndoEntry):
    def __init__(self, nodeName, paramName, newParamName, oldParentName, oldIndex, newParentName, newIndex) -> None: ...
    def doReparent(self, fromParentName, fromName, toParentName, toIndex, toName): ...
    def getName(self): ...
    def redo(self): ...
    def undo(self): ...

class parameter_replaceXML_UndoEntry(Utils.UndoStack.UndoEntry):
    def __init__(self, parameterFullName, undoXML, redoXML) -> None: ...
    def getName(self): ...
    def redo(self): ...
    def undo(self): ...

class parameter_setName_UndoEntry(Utils.UndoStack.UndoEntry):
    def __init__(self, parameterParentFullName, undoName, redoName) -> None: ...
    def getName(self): ...
    def redo(self): ...
    def undo(self): ...

class parameter_setValue_UndoEntry(Utils.UndoStack.UndoEntry):
    def __init__(self, parameterFullName, undoXML, redoXML) -> None: ...
    def getName(self): ...
    def redo(self): ...
    def undo(self): ...

class port_connect_UndoEntry(Utils.UndoStack.UndoEntry):
    def __init__(self, nodeNameA: str, portNameA: str, nodeNameB: str, portNameB: str, portA: NodegraphAPI.Port, portB: NodegraphAPI.Port, oldSourceNode: str | None, oldSourcePort: str | None, portC: NodegraphAPI.Port | None) -> None: ...
    def getName(self): ...
    def redo(self): ...
    def undo(self): ...

class port_disconnect_UndoEntry(Utils.UndoStack.UndoEntry):
    def __init__(self, nodeNameA, portNameA, nodeNameB, portNameB, portA, portB, isPortASendPort, isPortBReturnPort, nodeAShapeAttrs, nodeBShapeAttrs) -> None: ...
    def getName(self): ...
    def redo(self): ...
    def undo(self): ...

class port_metadataUpdated_UndoEntry(Utils.UndoStack.UndoEntry):
    def __init__(self, port: NodegraphAPI.Port, oldMetadata, newMetadata) -> None: ...
    def _port_metadataUpdated_UndoEntry__clearMetadata(self): ...
    def getName(self): ...
    def getNode(self) -> NodegraphAPI.Node: ...
    def getPort(self): ...
    def redo(self): ...
    def undo(self): ...

class port_setTags_UndoEntry(Utils.UndoStack.UndoEntry):
    def __init__(self, port: NodegraphAPI.Port, newTags, oldTags) -> None: ...
    def getName(self): ...
    def getPort(self) -> NodegraphAPI.Port | None: ...
    def redo(self): ...
    def undo(self): ...

class roto_event_UndoEntry(Utils.UndoStack.UndoEntry):
    def __init__(self, rotoUE, nodeName) -> None: ...
    def getName(self): ...
    def redo(self): ...
    def undo(self): ...

def _Undo_Filter(eventType, eventID, **kwargs): ...
def __node_addInputPort_Undo(eventType, eventID, nodeName, portName, portIndex, **kwargs): ...
def __node_addOutputPort_Undo(eventType, eventID, nodeName, portName, portIndex, **kwargs): ...
def __node_beginRemoveInputPort_Undo(eventType, eventID, nodeName, portName, port: NodegraphAPI.Port, **kwargs): ...
def __node_create_Undo(eventType, eventID, node: NodegraphAPI.Node, nodeName, nodeType, **kwargs): ...
def __node_paste_Undo(eventType, eventID, nodeNames, nodeParentName, xmlElement, **kwargs): ...
def __node_removeInputPort_Undo(eventType, eventID, nodeName, portName, port: NodegraphAPI.Port, **kwargs): ...
def __node_removeOutputPort_Undo(eventType, eventID, nodeName, portName, port: NodegraphAPI.Port, **kwargs): ...
def __node_renameInputPort_Undo(eventType, eventID, nodeName, oldPortName, newPortName, **kwargs): ...
def __node_renameOutputPort_Undo(eventType, eventID, nodeName, oldPortName, newPortName, **kwargs): ...
def __node_setAutoRenameAllowed_Undo(eventType, eventID, node: NodegraphAPI.Node, nodeName, **kwargs): ...
def __node_setBypassRouting_Undo(eventType, eventID, node: NodegraphAPI.Node, nodeName, **kwargs): ...
def __node_setBypassed_Undo(eventType, eventID, node: NodegraphAPI.Node, nodeName, **kwargs): ...
def __node_setName_Undo(eventType, eventID, node: NodegraphAPI.Node, newName, oldName, **kwargs): ...
def __node_setParent_Undo(eventType, eventID, nodeName, oldParentName, newParentName, **kwargs): ...
def __node_setPosition_Undo(eventType, eventID, nodeName, oldPosition, newPosition, **kwargs): ...
def __node_setThumbnailEnabled_Undo(eventType, eventID, node: NodegraphAPI.Node, nodeName, thumbnailEnabled, oldThumbnailEnabled): ...
def __node_setType_Undo(eventType, eventID, node: NodegraphAPI.Node, nodeName, **kwargs): ...
def __node_shapeAttrsChanged_Undo(eventType, eventID, nodeName, oldAttrs, newAttrs, **kwargs): ...
def __parameter_createChild_Undo(eventType, eventID, param, paramName, childParam, element, index, **kwargs): ...
def __parameter_deleteChild_Undo(eventType, eventID, param, paramName, element, childName, index, **kwargs): ...
def __parameter_reorderChild_Undo(eventType, eventID, paramName, oldIndex, newIndex, **kwargs): ...
def __parameter_reorderChildren_Undo(eventType, eventID, paramName, oldIndex, newIndex, count, **kwargs): ...
def __parameter_reparentAtomic_Undo(eventType, eventID, param, paramName, newParamName, nodeName, oldParentName, oldIndex, newParentName, **kwargs): ...
def __parameter_replaceXML_Undo(eventType, eventID, param, oldXML, newXML, paramName, **kwargs): ...
def __parameter_setName_Undo(eventType, eventID, paramParentName, oldName, newName, **kwargs): ...
def __port_connect_Undo(eventType, eventID, portA, nodeNameA, portNameA, portB, nodeNameB, portNameB, **kwargs): ...
def __port_disconnect_Undo(eventType, eventID, portA, nodeNameA, portNameA, portB, nodeNameB, portNameB, isPortASendPort: bool = ..., isPortBReturnPort: bool = ..., nodeAShapeAttrs: Incomplete | None = ..., nodeBShapeAttrs: Incomplete | None = ..., **kwargs): ...
def __port_metadataUpdated_Undo(_eventType, _eventID, port: NodegraphAPI.Port, oldMetadata, newMetadata): ...
def __port_setTags_Undo(eventType, eventID, nodeName, port: NodegraphAPI.Port, portName, newTags, oldTags, **kwargs): ...
def __roto_event_Undo(eventType, eventID, rotoUE, nodeName, **kwargs): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from UI4.Widgets.IndicatorLabelFrame import IndicatorLabelFrame as IndicatorLabelFrame
from _typeshed import Incomplete
from typing import Set, Tuple

class AttributeEditorIndicatorLabel(IndicatorLabelFrame):
    def __init__(self, parent: Incomplete | None = ...) -> None: ...
    def setDisplay(self, editable: bool, message: str = ..., nodeName: str = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import ResourceFiles as ResourceFiles
import UI4 as UI4
import Utils as Utils
import QT4Widgets.WidgetUtils as WidgetUtils
from QT4Widgets.SortableTreeWidget import SortableTreeWidget as SortableTreeWidget, SortableTreeWidgetItem as SortableTreeWidgetItem
from ResourceFiles.IconManager import ResourceManager as ResourceManager
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class FilterableCombo(PyQt5.QtWidgets.QWidget):
    class FocusSignalingLineEdit(PyQt5.QtWidgets.QLineEdit):
        focusIn: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
        def focusInEvent(self, event): ...
    refreshItems: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    textChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, label, parent) -> None: ...
    def _FilterableCombo__fieldChanged(self): ...
    def _FilterableCombo__fieldFocusIn(self): ...
    def _FilterableCombo__popupAboutToShow(self): ...
    def _FilterableCombo__popupItemChosen(self, item, meta: Incomplete | None = ...): ...
    def event(self, event): ...
    def setItems(self, itemList): ...
    def setText(self, text, strict: bool = ...): ...
    def text(self): ...

class FilterablePopup(PyQt5.QtWidgets.QFrame):
    aboutToShow: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    arrowKeyPress: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    deleteKeyPress: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    hideSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    itemChosen: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    released: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    returnKeyPress: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    shiftKeyPress: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    showSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent: Incomplete | None = ...) -> None: ...
    def _FilterablePopup__buildWidgets(self): ...
    def _FilterablePopup__calculateGeometry(self) -> PyQt5.QtCore.QRect: ...
    def _FilterablePopup__chooseCurrent(self): ...
    def _FilterablePopup__clearFilterField(self): ...
    def _FilterablePopup__findScreen(self, desktop: PQDesktopWidget, globalPos: QPoint) -> int: ...
    def _FilterablePopup__findTabOrScrollAreaRect(self) -> QRect | None: ...
    def _FilterablePopup__findXYToFitInRect(self, currentPopupRect: QRect, enclosingRect: QRect) -> Tuple[int, int]: ...
    def _FilterablePopup__firstSelectedItem(self): ...
    def _FilterablePopup__itemChosen(self, item): ...
    def _FilterablePopup__mouseMoved(self, event): ...
    def _FilterablePopup__on_filterCombobox_activated(self, index): ...
    def _FilterablePopup__popupArrowKeyPress(self, key): ...
    def _FilterablePopup__popupReturnKeyPress(self, key): ...
    def _FilterablePopup__released(self): ...
    def _FilterablePopup__updateFilter(self, text: Incomplete | None = ...): ...
    def _buildTreeWidget(self): ...
    def addFilterByOption(self, name, callbackFnc): ...
    def addItem(self, text, pixmap: Incomplete | None = ..., meta: Incomplete | None = ..., item: Incomplete | None = ..., parentToItem: Incomplete | None = ...): ...
    def addOption(self, displayText, optionValues, defaultValue, callbackFnc, callbackWithIndex: bool = ...): ...
    def addSwitch(self, displayText, defaultValue, callbackFnc) -> PyQt5.QtWidgets.QCheckBox: ...
    def applyDefaultSize(self): ...
    def bottomToolbar(self): ...
    def chooseCustom(self, value, meta: Incomplete | None = ...): ...
    def clear(self): ...
    def clearFilterField(self): ...
    def displayActivityIndicator(self, display): ...
    def event(self, event): ...
    def focusFilterField(self): ...
    def getDesiredHeight(self): ...
    def getDesiredWidth(self): ...
    def getMaxScreenHeightPercentage(self) -> float: ...
    def getMaxScreenWidthPercentage(self) -> float: ...
    def getOption(self, name): ...
    def getWidgetSwitchArea(self): ...
    def hideEvent(self, e): ...
    def popup(self, globalPos): ...
    def selectItem(self, text): ...
    def setDesiredHeight(self, height): ...
    def setDesiredWidth(self, width): ...
    def setIconSize(self, size): ...
    def setMaxScreenHeightPercentage(self, maxScreenHeightPercentage: float): ...
    def setMaxScreenWidthPercentage(self, maxScreenWidthPercentage: float): ...
    def setSorting(self, state): ...
    def showEvent(self, e): ...
    def switchBox(self): ...
    def treeWidget(self): ...
    def updateActivityIndicator(self): ...
    def updateFilter(self): ...

class FilterablePopupButton(PyQt5.QtWidgets.QPushButton):
    aboutToShow: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    itemChosen: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    popupClosed: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent: Incomplete | None = ..., buttonType: Incomplete | None = ...) -> None: ...
    def _FilterablePopupButton__popClicked(self): ...
    def _FilterablePopupButton__popupHidden(self): ...
    def _FilterablePopupButton__popupShow(self): ...
    def _buildPopupWindow(self): ...
    def forceUIUpdate(self): ...
    def getPopupWindow(self): ...
    def setButtonType(self, buttonType): ...
    def __del__(self) -> None: ...
    def __getattr__(self, name): ...

class _DeleteEatingLineEdit(PyQt5.QtWidgets.QLineEdit):
    deleteKeyPress: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def keyPressEvent(self, event): ...

class _TrackingTreeWidget(SortableTreeWidget):
    released: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    rightClick: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, *args) -> None: ...
    def event(self, event): ...
    def leaveEvent(self, e): ...
    def mouseMoveEvent(self, e): ...
    def mousePressEvent(self, e): ...
    def mouseReleaseEvent(self, e): ...
    def showEvent(self, event): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4 as UI4
from . import AttributeValuePopupWidgetManager as AttributeValuePopupWidgetManager, Bridge as Bridge, BridgeImpl as BridgeImpl, ColumnManager as ColumnManager, ColumnPresetManager as ColumnPresetManager, ContextMenuEvent as ContextMenuEvent, DataRoles as DataRoles, DebugViewLink as DebugViewLink, Filtering as Filtering, ItemDelegates as ItemDelegates, SceneGraphFindButton as SceneGraphFindButton, SceneGraphHandle as SceneGraphHandle, SceneGraphLocationTranslation as SceneGraphLocationTranslation, SceneGraphTree as SceneGraphTree, SceneGraphViewClientManager as SceneGraphViewClientManager, SceneGraphViewColumn as SceneGraphViewColumn, SceneGraphViewIconManager as SceneGraphViewIconManager, TreeWidgetItems as TreeWidgetItems, TreeWidgetViewLink as TreeWidgetViewLink, ViewLink as ViewLink
from UI4.Widgets.SceneGraphView.ColumnDataType import ColumnDataType as ColumnDataType, RegisterDataType as RegisterDataType
from UI4.Widgets.SceneGraphView.HorizontalHeaderView import HorizontalHeaderView as HorizontalHeaderView
from UI4.Widgets.SceneGraphView.SceneGraphView import SceneGraphView as SceneGraphView
from typing import Set, Tuple



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Util.IconManager as IconManager
import PyQt5.QtCore
import PyQt5.QtWidgets
import PyServiceProviderRegistry
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
from typing import ClassVar, Set, Tuple

class ServiceProviderItemDelegate(PyQt5.QtWidgets.QStyledItemDelegate):
    kIconSize: ClassVar[int] = ...
    kPadding: ClassVar[int] = ...
    def __init__(self, listWidget, parent) -> None: ...
    def paint(self, painter: PyQt5.QtWidgets.QPainter, option: PyQt5.QtWidgets.QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex): ...
    def sizeHint(self, option: PyQt5.QtWidgets.QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex) -> PyQt5.QtCore.QSize: ...

class ServiceProviderListWidget(PyQt5.QtWidgets.QWidget):
    kHealthCheckSupportedRole: ClassVar[int] = ...
    kServiceFooterTextRole: ClassVar[int] = ...
    kServiceNameRole: ClassVar[int] = ...
    kServiceObjectRole: ClassVar[int] = ...
    kServiceVersionRole: ClassVar[int] = ...
    serviceProviderSelectionCancelled: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    serviceProviderSelectionChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent: PyQt5.QtWidgets.QWidget) -> None: ...
    @classmethod
    def PixmapForService(cls, service): ...
    @classmethod
    def ServiceIDForService(cls, service): ...
    @classmethod
    def ServiceNameForService(cls, service: PyServiceProviderRegistry.ServiceProvider) -> str: ...
    def _ServiceProviderListWidget__idle(self, *args, **kwargs): ...
    def _ServiceProviderListWidget__setupUI(self): ...
    def _ServiceProviderListWidget__updateModel(self): ...
    def _ServiceProviderListWidget__updateModelItem(self, serviceItem, service): ...
    def hideEvent(self, event): ...
    def on_serviceSelectionModel_currentRowChanged(self, current: PyQt5.QtCore.QModelIndex, previous: PyQt5.QtCore.QModelIndex): ...
    def showEvent(self, event): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

STATE_MIXED: int
STATE_OFF: int
STATE_ON: int

class MixedGroupState:
    def __init__(self) -> None: ...
    def _MixedGroupState__resolveState(self): ...
    def addState(self, state): ...
    def getState(self): ...
    def removeState(self, state): ...
    def swapState(self, fromState, toState): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import PyFnAttribute as FnAttribute
import GeolibRuntime
import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import Nodes3DAPI as Nodes3DAPI
import PyUtilModule.ProjectSnapshot as ProjectSnapshot
import PyUtilModule.RenderManager.RenderGlobals as RenderGlobals
import RenderingAPI as RenderingAPI
from PyUtilModule.RenderManager.Constants import RenderModes as RenderModes
from PyUtilModule.RenderManager.Exceptions import UnsupportedRenderMethodNameException as UnsupportedRenderMethodNameException
from typing import ClassVar, Set, Tuple

class RenderingSettings:
    kOpTreeExportPass: ClassVar[int] = ...
    kOpTreeRenderPass: ClassVar[int] = ...
    def __init__(self) -> None: ...
    def setDefaults(self): ...

def CheckGlobalSettings(settings): ...
def GetRendererAndSettings(settings: RenderingSettings, renderMethodName: str, renderOpNode: NodegraphAPI.Node, runtime: GeolibRuntime, txn: GeolibRuntimeTransaction, client: GeolibRuntime.Client) -> tuple[str, str, GeolibRuntimeOp]: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Callbacks as Callbacks
import CatalogAPI as CatalogAPI
import ConfigurationAPI_cmodule as Configuration
import Utils.EventModule as EventModule
import PyFnAttribute as FnAttribute
import PyFnGeolib as FnGeolib
import PyFnGeolibServices as FnGeolibServices
import GeoAPI as GeoAPI
import PyUtilModule.LiveRenderAPI as LiveRenderAPI
import RerenderEventMapper.LiveRenderPortOpObserver as LiveRenderPortOpObserver
import Nodes3DAPI.Node3D_geolib3 as Node3D_geolib3
import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import Nodes3DAPI as Nodes3DAPI
import PyFnAttribute
import PyFnGeolib
import PyQt5.QtCore as QtCore
import PyUtilModule.RenderManager.RenderCore as RenderCore
import PyUtilModule.RenderManager.RenderGlobals as RenderGlobals
import PyUtilModule.RenderManager as RenderManager
import RenderingAPI as RenderingAPI
import PyUtilModule.RenderingCommon as RenderingCommon
import Nodes3DAPI.UpdateModes as UpdateModes
import Utils as Utils
import collections
from PyUtilModule.WorkingSet import WorkingSet as WorkingSet, __renderWorkingSet as __renderWorkingSet, __workingSet as __workingSet
from PyUtilModule.WorkingSetClient import WorkingSetClient as WorkingSetClient
from PyUtilModule.WorkingSetManager import WorkingSetManager as WorkingSetManager
from _typeshed import Incomplete
from typing import Any, Set, Tuple

ForesightPlusEnabled: bool
__allowFollowRenderWorkingSet: bool
__areEventHandlersRegistered: bool
__areIRFsOpsDirty: bool
__cachedViewerMatrixArgs: None
__client: None
__cookedInitialLocations: set
__deferredLocationEvents: dict
__hadManualUpdateEvent: bool
__initialStateClient: None
__initialStateRuntime: None
__inputOpToLiveRenderOpChain: None
__interactiveRenderFiltersPorts: list
__irfPort: None
__liveAttributeWorker: None
__liveRenderDeferredRemovalTerminalOps: list
__liveRenderTerminalOps: dict
__locAttrHashCache: collections.defaultdict
__locationTypeCache: collections.defaultdict
__oldLightList: None
__pruneOpChain: None
__queuedUpdates: collections.deque
__renderOp: None
__renderPort: None
__runtime: None
__sendFullUpdateForNewLocation: bool
__terminalOpDelegatesRootOp: None
__terminalOps: list
__terminalOpsRootOp: None
__viewedGraphStateHash: None
__virtualCameraSSCOp: None
kVirtualCameraSceneGraphLocation: str

class LiveAttributeWorker:
    def __init__(self, runtime, client: Incomplete | None = ...) -> None: ...
    def applyQueuedAttributeChanges(self): ...
    def canApplyUpdate(self) -> bool: ...
    def getLiveAttributeOp(self) -> PyFnGeolib.GeolibRuntimeOp: ...
    def queueLiveAttribute(self, locationPath, attrValue, attrPath: str = ...): ...
    def setClient(self, client: PyFnGeolib.GeolibRuntime.client): ...
    def setLiveAttributeOp(self, liveAttrOp: PyFnGeolib.GeolibRuntimeOp): ...

def AddSettingsToRerenderRecipe(): ...
def ApplyTerminalOpDelegates(inputOp: PyFnGeolib.GeolibRuntimeOp, txn: transaction): ...
def CheckLiveRenderSettings(attributes: PyFnAttribute.GroupAttribute): ...
def CheckOutputsRenderSettings(attributes: PyFnAttribute.GroupAttribute, mainSequenceID: Incomplete | None = ...): ...
def GetAppliedTerminalOps() -> list[tuple[Any, str, PyFnAttribute.GroupAttribute]]: ...
def GetChangedAttributes(locationPath: str, locationAttrs: PyFnAttribute, locationType: str, sendFullUpdate: bool = ...): ...
def GetDefaultTerminalOps(txn: transaction, opInput) -> list[PyFnGeolib.GeolibRuntimeOp]: ...
def GetDeletedLocationsUpdate(deletedLocations: list[str]) -> PyFnAttribute.GroupAttribute: ...
def GetInteractiveRenderFiltersOps(opInput: PyFnGeolib.GeolibRuntimeOp, activatePorts: bool = ...) -> list[PyFnGeolib.GeolibRuntimeOp]: ...
def GetLightListChanges(location: str, locationAttrs): ...
def GetLiveRenderNodeAndPort() -> Tuple[Node3D, port]: ...
def GetRenderCameraChanges(location: str, locationAttrs: PyFnAttribute.GroupAttribute): ...
def GetWatchedAttributeGroups(liveRenderAttrs: PyFnAttribute.GroupAttribute) -> dict: ...
def GetWatchedAttributes(attrToWatch: PyFnAttribute.GroupAttribute, prefix: str = ...) -> list: ...
def HasHashChanged(locationPath, attrName: str, newAttr: PyFnAttribute) -> bool: ...
def InitializeGeolib3Client(): ...
def OnCancelled(): ...
def OnCompleted(): ...
def OnErrored(): ...
def OnIdle(): ...
def OnLiveRenderClearAllTerminalOps(eventType, eventID): ...
def OnLiveRenderInsertTerminalOp(eventType: str, eventID: object, opKey: Incomplete | None = ..., opType: str = ..., opArgs: Incomplete | None = ..., insertIndex: Incomplete | None = ...): ...
def OnLiveRenderRemoveTerminalOp(eventType: str, eventID: object, opKey: Incomplete | None = ..., deferred: bool = ...): ...
def OnLiveRenderRestoreDefaultTerminalOps(eventType, eventID): ...
def OnManualUpdate(eventType: str, eventID: object, updateMode: Incomplete | None = ...): ...
def OnNodeDeleted(eventType: str, eventID: object, node: NodegraphAPI.Node, oldName: str): ...
def OnNodeRenamed(eventType: str, eventID: object, node: NodegraphAPI.Node, oldName: str, newName: str): ...
def OnNodeSetBypassed(eventType, eventID, node: NodegraphAPI.Node, **kwargs): ...
def OnParameterFinalize(eventType, eventID, param, **kwargs): ...
def OnRerenderCameraChanged(eventType: str, eventID: object, cameraType: Incomplete | None = ..., cameraPath: Incomplete | None = ...): ...
def OnRoiChanged(): ...
def OnSendCommand(): ...
def OnSendData(): ...
def OnSetCurrentTime(eventType: str, eventID: object): ...
def OnStarted(): ...
def OnStop(): ...
def OnStopped(sequenceIDs): ...
def OnUpdate(): ...
def OnUpdateModeChanged(eventType: str, eventID: object, updateMode: Incomplete | None = ...): ...
def OnViewMatrixChanged(): ...
def OnViewerLiveAttributeChanged(eventType: str, eventID: object, locationPath: str, attrPath: str, attrValue: PyFnAttribute.Attribute): ...
def OnVisibilityFollowsWorkingSetChanged(eventType, eventID, visibilityFollowsWorkingSet): ...
def QueueRenderSettingsSequenceIDMapAttributeUpdate(mainSequenceIDs: list[int]): ...
def SetLiveAttribute(locationPath: str, attrPath: str, attrValue: PyFnAttribute.Attribute, attrEditor: Incomplete | None = ...): ...
def SetVirtualCameraAttributes(attributes: PyFnAttribute.Attribute): ...
def StartGeolib3Listening(): ...
def StopGeolib3Listening(): ...
def StopRerender(): ...
def UnregisterEventHandlers(): ...
def _GetGeolibServiceHostAndPort(mainSequenceID): ...
def _SendForesightCommand(mainSequenceID, command): ...
def _UpdateVirtualCameraSSCOpArgs(txn): ...
def __RemoveDeferredTerminalOps(): ...
def __RemoveTerminalOp(opKey: object): ...
def __createPruneOpChain(txn): ...
def __createRenderWorkingSetResolveOp(txn): ...
def __createRenderWorkingSetSetupOp(txn): ...
def __deferUntilOriginalLocationCooked(location: str) -> bool: ...
def __emitCachedViewMatrixChanged(): ...
def __getIRFsOpAndPorts(sourceGraphState: Incomplete | None = ...): ...
def __interactiveRenderFilterOpCallback(port: NodegraphAPI.Port, graphState: NodegraphAPI.GraphState, op, transaction): ...
def __interactiveRenderFiltersGetOpFunction(sourceNode, sourcePort, sourceGraphState, visitedState, txn): ...
def __processInitialStateEvents() -> list[LocationEvent]: ...
def __registerEventHandlers(rerenderNodeName): ...
def __setPruneOpChainInputOpArgs(): ...
def __terminalOpCallback(port: NodegraphAPI.Port, graphState: NodegraphAPI.GraphState, op, transaction): ...
def __unregisterEventHandlers(): ...
def changeVisibilityFollowsWorkingSet(visibilityFollowsWorkingSet): ...
def getImplicitTerminalOps(txn: transaction, opInput: PyFnGeolib.GeolibRuntimeOp, renderNode: NodegraphAPI.Node) -> list[PyFnGeolib.GeolibRuntimeOp]: ...
def liveRenderWorkingSetClearedCallback(workingSet): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4.Widgets.SortablePanel as SortablePanel
import UI4.Widgets.SortablePanel
import Utils as Utils
from typing import Set, Tuple

class GroupPanel(UI4.Widgets.SortablePanel.ParameterSortablePanel):
    def __init__(self, parent, name, policy, factory, reorderable: bool = ..., deletable: bool = ..., onlyLastDeletable: bool = ...) -> None: ...
    def getValuePolicy(self): ...
    def getWidget(self): ...
    def setIndex(self, index): ...
    def setLocked(self, value): ...
    def updateWidgetState(self): ...

class SortableGroupsFormWidget(UI4.Widgets.SortablePanel.ParameterSortablePanelFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _SortableGroupsFormWidget__getNode(self): ...
    def _getPanelForPolicy(self, vp): ...
    def addEntry(self): ...
    def buildAddMenu(self, menu): ...
    def panelDeleted(self, index): ...
    def panelReordered(self, oldPos, newPos): ...
    def updatePanelWidgets(self): ...
    def updatePanels(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import BaseNodeActionDelegate as BaseNodeActionDelegate, DisplayOutputsActionDelegate as DisplayOutputsActionDelegate, GroupActionDelegate as GroupActionDelegate, LiveGroupActionDelegate as LiveGroupActionDelegate, NodeActionDelegate as NodeActionDelegate
from UI4.FormMaster.NodeActionDelegate.NodeActionDelegate import RegisterActionDelegate as RegisterActionDelegate, UpdateContextMenuWithDelegates as UpdateContextMenuWithDelegates, UpdateWrenchMenuWithDelegates as UpdateWrenchMenuWithDelegates
from typing import Set, Tuple



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Any, Set, Tuple

class Criteria:
    def __init__(self, numberOfElements: int = ...) -> None: ...
    def getAsFloat(self) -> tuple[float, ...]: ...
    def getAsInt(self) -> tuple[int, ...]: ...
    def getAsObject(self) -> tuple[Any, ...]: ...
    def getAsString(self) -> tuple[str, ...]: ...
    def setValue(self, index: int, value): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtGui
import QT4FormWidgets as QT4FormWidgets
import QT4FormWidgets.InputWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from typing import ClassVar, Set, Tuple

class ColorTextValidator(PyQt5.QtGui.QValidator):
    def __init__(self, *args) -> None: ...
    def parseColor(self, text): ...
    def validate(self, inStr, qPos): ...

class ColorTextWidget(QT4FormWidgets.InputWidgets.InputLineEdit):
    valueChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent) -> None: ...
    def _ColorTextWidget__updateText(self): ...
    def _ColorTextWidget__valueChangedCB(self): ...
    def getColorText(self, color): ...
    def keyPressEvent(self, event): ...
    def setColor(self, color): ...

def ColorFromText(text): ...
def ColorToText(color, roundDigits: int = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import UI4 as UI4
import Utils as Utils
from UI4.Widgets.ToolbarButton import ToolbarButton as ToolbarButton
from _typeshed import Incomplete
from typing import Set, Tuple

class AutoKeyAllToggle(ToolbarButton):
    def __init__(self, parent: Incomplete | None = ...) -> None: ...
    def _AutoKeyAllToggle__on_clicked(self): ...
    def _AutoKeyAllToggle__on_parameter_setAutoKeyAll(self, eventType, eventID, **kwargs): ...
    def _AutoKeyAllToggle__updateIcon(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import DrawingModule as DrawingModule
import NodegraphAPI as NodegraphAPI
import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import QT4GLLayerStack as QT4GLLayerStack
import QT4GLLayerStack.LayerStack
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import Utils as Utils
import typing
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class DefaultColorPanel(PyQt5.QtWidgets.QFrame):
    class ColorEntry(PyQt5.QtWidgets.QFrame):
        colorSelected: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
        def __init__(self, color, emitFromWidget, *args) -> None: ...
        def enterEvent(self, ev): ...
        def leaveEvent(self, ev): ...
        def mousePressEvent(self, ev): ...
        def paintEvent(self, ev): ...
        def sizeHint(self): ...
        def sizePolicy(self): ...
    _DefaultColorPanel__hues: ClassVar[list] = ...
    colorSelected: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, *args) -> None: ...

class EditBackdropNodeDialog(PyQt5.QtWidgets.QDialog):
    DEFAULT_GREY: ClassVar[float] = ...
    MIN_FONTSCALE: ClassVar[float] = ...
    def __init__(self, node: NodegraphAPI.Node, previewCallback: typing.Optional[typing.Callable] = ...) -> None: ...
    def _EditBackdropNodeDialog__buildWidgets(self): ...
    def _EditBackdropNodeDialog__connectSignals(self): ...
    def _EditBackdropNodeDialog__finalizeNodeAttrs(self): ...
    def _EditBackdropNodeDialog__fontScaleChanged(self, event): ...
    def _EditBackdropNodeDialog__fontScaleEdited(self, text): ...
    def _EditBackdropNodeDialog__setColor(self, event): ...
    def _EditBackdropNodeDialog__setShapeAttrs(self, **attrs): ...
    def _EditBackdropNodeDialog__setText(self): ...
    def _EditBackdropNodeDialog__updateFontScale(self, fontScale): ...
    def accept(self): ...
    def getColor(self): ...
    def getFontScale(self): ...
    def getShowInBookmarks(self): ...
    def getText(self): ...
    def reject(self): ...

class StickyNoteInteractionLayer(QT4GLLayerStack.LayerStack.Layer):
    def __init__(self, *args, **kwargs) -> None: ...
    @staticmethod
    def _StickyNoteInteractionLayer__calcNodeAreaSq(node: NodegraphAPI.Node): ...
    def _StickyNoteInteractionLayer__findBackdropChildren(self, backdropNode): ...
    def _StickyNoteInteractionLayer__findBackdropDescendants(self, backdropNode): ...
    def _StickyNoteInteractionLayer__handleBackdropClicked(self, backdropNode, event): ...
    def _StickyNoteInteractionLayer__node_delete_cb(self, eventType, eventID, node: NodegraphAPI.Node, *args, **kwargs): ...
    def _StickyNoteInteractionLayer__node_shapeAttr_changed(self, node: NodegraphAPI.Node, attrDict): ...
    def processEvent(self, event): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConditionalStateGrammar as ConditionalStateGrammar
import Nodes3DAPI.DynamicParameterUtil as DynamicParameterUtil
import PyFnAttribute as FnAttribute
import NodegraphAPI as NodegraphAPI
from ConditionalStateGrammar.Parser import ParseCSG as ParseCSG
from Nodes3DAPI.Node3D import Node3D as Node3D
from Nodes3DAPI_cmodule import BuildAttrListFromDynamicParameterGroup as BuildAttrListFromDynamicParameterGroup
from _typeshed import Incomplete
from typing import Set, Tuple

_ExtraHints: dict

class IncomingTestNode(Node3D):
    def __init__(self) -> None: ...
    def _IncomingTestNode__getScenegraphLocation(self, frameTime, action: Incomplete | None = ..., name: Incomplete | None = ..., location: Incomplete | None = ...): ...
    def _getIncomingSceneOpAndLocation(self, port: NodegraphAPI.Port, graphState: NodegraphAPI.GraphState, transaction): ...
    def _getOpChain(self, interface): ...
    def _updateParameters(self, groupAttr, force: bool = ..., defaultAttr: Incomplete | None = ...): ...
    def addParameterHints(self, attrName, inputDict): ...
    def getScenegraphLocation(self, frameTime: int = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import BrowserFiltering as BrowserFiltering, BrowserSettings as BrowserSettings, FileInfo as FileInfo
from QT4Browser.FileBrowser import FileBrowser as FileBrowser
from QT4Browser.FileInfo import AbstractFileTableModel as AbstractFileTableModel, FileInfoDisplay as FileInfoDisplay, FileInfoItem as FileInfoItem, FileTableView as FileTableView, IsDir as IsDir
from QT4Browser.FileSelect import FileSelect as FileSelect
from typing import Set, Tuple



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
from QT4FormWidgets.FormWidget import FormWidget
from UI4.FormMaster.Editors.NodeDropWidget import NodeDropWidget as NodeDropWidget
from typing import ClassVar, Set, Tuple

class NodeDropLabel(PyQt5.QtWidgets.QLabel):
    nodeDropped: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent) -> None: ...
    def dragEnterEvent(self, event): ...
    def dropEvent(self, event): ...

class NodeProxyPlaceholderWidget(FormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _NodeProxyPlaceholderWidget__buildOrUpdateDropWidget(self): ...
    def _NodeProxyPlaceholderWidget__nodeDropped(self, path): ...
    def decorateUserParameterFrame(self, parent): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Util.NotificationManager as NotificationManager
import Utils as Utils
from typing import Set, Tuple

def _TooNewFileOpenedListener(eventType, eventID, sourceFile, sourceVersion, currentVersion): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyXmlIO as PyXmlIO
import Naming as UniqueName
import Utils as Utils
from Utils.Decorators import deprecated as deprecated
from _typeshed import Incomplete
from typing import Set, Tuple

def Document_getReleaseTag(doc: PyXmlIO.Element) -> str: ...
def Document_getRootNode(doc: PyXmlIO.Element) -> PyXmlIO.Element: ...
def Document_getSharedNodes(doc: PyXmlIO.Element) -> list[PyXmlIO.Element]: ...
def Document_getVersionTag(doc: PyXmlIO.Element) -> str: ...
def Document_isInstance(element: PyXmlIO.Element, error: bool = ...) -> bool: ...
def Document_setReleaseTag(doc: PyXmlIO.Element, releaseTag: str): ...
def Document_setVersionTag(doc: PyXmlIO.Element, versionTag: str): ...
def FCurve_getKeyValuePairs(curve: PyXmlIO.Element): ...
def FCurve_isInstance(element: PyXmlIO.Element, error: bool = ...) -> bool: ...
def FCurve_offsetCurve(curve: PyXmlIO.Element, offsetX: float, offsetY: float) -> PyXmlIO.Element: ...
def FCurve_setName(curve: PyXmlIO.Element, name: str): ...
def GetAllNodes(rootNodeOrDoc: PyXmlIO.Element) -> list[PyXmlIO.Element]: ...
def GetAllNodesAndParents(rootNode: PyXmlIO.Element): ...
def GetNode(rootNodeOrDoc: PyXmlIO.Element, nodeName: str) -> PyXmlIO.Element | None: ...
def Node_addInputPort(node: PyXmlIO.Element, portName: str): ...
def Node_addOutputPort(node: PyXmlIO.Element, portName: str): ...
def Node_createChildNode(doc: PyXmlIO.Element, node: PyXmlIO.Element, nodeName: str, nodeType: str, nodeBaseType: Incomplete | None = ...): ...
def Node_createParameter(node: PyXmlIO.Element, parmName: str, parmType: str): ...
def Node_deleteChildByName(node: PyXmlIO.Element, childName: str): ...
def Node_deleteInputPort(node: PyXmlIO.Element, portName: str): ...
def Node_deleteOutputPort(node: PyXmlIO.Element, portName: str) -> PyXmlIO.Element: ...
def Node_deleteParameter(node: PyXmlIO.Element, parmName: str): ...
def Node_getBypassed(node: PyXmlIO.Element) -> bool: ...
def Node_getChildByName(node: PyXmlIO.Element, childName: str) -> PyXmlIO.Element: ...
def Node_getChildren(node: PyXmlIO.Element) -> list[PyXmlIO.Element]: ...
def Node_getInputPort(node: PyXmlIO.Element, portName: str) -> PyXmlIO.Element: ...
def Node_getInputPorts(node: PyXmlIO.Element) -> list[PyXmlIO.Element]: ...
def Node_getName(node: PyXmlIO.Element) -> str: ...
def Node_getOutputPort(node: PyXmlIO.Element, portName: str) -> PyXmlIO.Element: ...
def Node_getOutputPorts(node: PyXmlIO.Element) -> list[PyXmlIO.Element]: ...
def Node_getParameter(node: PyXmlIO.Element, parmName: str) -> PyXmlIO.Element: ...
def Node_getParameters(node: PyXmlIO.Element) -> PyXmlIO.Element: ...
def Node_getPorts(node: PyXmlIO.Element) -> list[PyXmlIO.Element]: ...
def Node_getPosition(node: PyXmlIO.Element) -> tuple[float, float]: ...
def Node_getType(node: PyXmlIO.Element) -> str: ...
def Node_getUniqueInputPortName(node: PyXmlIO.Element, portName: str) -> str: ...
def Node_getUniqueNodeName(doc: PyXmlIO.Element, name: str) -> str: ...
def Node_getUniqueOutputPortName(node: PyXmlIO.Element, portName: str) -> str: ...
def Node_insertPort(node: PyXmlIO.Element, port: PyXmlIO.Element, index: int = ...): ...
def Node_isEdited(node: PyXmlIO.Element) -> bool: ...
def Node_isInstance(element: PyXmlIO.Element, error: bool = ...) -> bool: ...
def Node_setBypassed(node: PyXmlIO.Element, bypassed: bool): ...
def Node_setColor(node: PyXmlIO.Element, r: float, g: float, b: float): ...
def Node_setEdited(node: PyXmlIO.Element, isEdited: bool): ...
def Node_setName(node: PyXmlIO.Element, name: str): ...
def Node_setPosition(node: PyXmlIO.Element, position: tuple[float, float]): ...
def Node_setThumbnail(node: PyXmlIO.Element, showThumbnail: bool): ...
def Node_setType(node: PyXmlIO.Element, nodeType: Incomplete | None = ..., nodeBaseType: Incomplete | None = ...): ...
def Parameter_addChild(parm: PyXmlIO.Element, child: PyXmlIO.Element, index: Incomplete | None = ...): ...
def Parameter_createChildByName(parm: PyXmlIO.Element, parmName: str, parmType: str): ...
def Parameter_createType(parmType: str) -> PyXmlIO.Element: ...
def Parameter_deleteChildByIndex(parm: PyXmlIO.Element, index: int): ...
def Parameter_deleteChildByName(parm: PyXmlIO.Element, parmName: str): ...
def Parameter_getAllChildren(rootParm: PyXmlIO.Element, parmName: str = ...) -> list[tuple[str, PyXmlIO.Element]]: ...
def Parameter_getArrayChildren(parm: PyXmlIO.Element) -> list[PyXmlIO.Element]: ...
def Parameter_getArraySize(parm: PyXmlIO.Element) -> int: ...
def Parameter_getChild(parm: PyXmlIO.Element, parmName: str) -> PyXmlIO.Element | None: ...
def Parameter_getChildByIndex(parm: PyXmlIO.Element, index: int) -> PyXmlIO.Element | None: ...
def Parameter_getChildIndex(parm: PyXmlIO.Element, parmName: str) -> int | None: ...
def Parameter_getChildren(parm: PyXmlIO.Element) -> list[PyXmlIO.Element]: ...
def Parameter_getHintsDict(parm: PyXmlIO.Element) -> dict: ...
def Parameter_getName(parm: PyXmlIO.Element) -> str: ...
def Parameter_getTupleSize(parm: PyXmlIO.Element) -> int: ...
def Parameter_getType(parm: PyXmlIO.Element) -> str: ...
def Parameter_getValue(parm: PyXmlIO.Element) -> str | float: ...
def Parameter_getValueDict(parm: PyXmlIO.Element) -> dict: ...
def Parameter_isInstance(element: PyXmlIO.Element, error: bool = ...) -> bool: ...
def Parameter_isNodeDefaultUsed(parm: PyXmlIO.Element) -> bool: ...
def Parameter_reorderChildByIndex(parm: PyXmlIO.Element, oldPos: int, newPos: int): ...
def Parameter_replaceChildByName(parm: PyXmlIO.Element, name: str, newChildParm: PyXmlIO.Element) -> PyXmlIO.Element | None: ...
def Parameter_setHintsDict(parm: PyXmlIO.Element, hintsDict: dict): ...
def Parameter_setName(parm: PyXmlIO.Element, parmName: str): ...
def Parameter_setTupleSize(parm: PyXmlIO.Element, newSize: int): ...
def Parameter_setType(parm: PyXmlIO.Element, newType: str): ...
def Parameter_setUseNodeDefault(parm: PyXmlIO.Element, useDefault: bool): ...
def Parameter_setValue(parm: PyXmlIO.Element, value: Incomplete | None = ..., expression: Incomplete | None = ..., fcurve: Incomplete | None = ..., isexpression: Incomplete | None = ..., autokey: Incomplete | None = ..., sample: Incomplete | None = ..., animated: Incomplete | None = ...): ...
def Parameter_setValueDict(parm: PyXmlIO.Element, valueDict: dict): ...
def Parameter_updateArraySize(parm: PyXmlIO.Element): ...
def Port_deleteMetadata(port: PyXmlIO.Element, metadataKey: str): ...
def Port_getMetadata(port: PyXmlIO.Element, metadataKey: str) -> str: ...
def Port_getName(port: PyXmlIO.Element) -> str: ...
def Port_getReturns(port: PyXmlIO.Element) -> str: ...
def Port_getSource(port: PyXmlIO.Element) -> str: ...
def Port_getTags(port: PyXmlIO.Element) -> list[str]: ...
def Port_getType(port: PyXmlIO.Element) -> str: ...
def Port_isInputPort(port: PyXmlIO.Element) -> bool: ...
def Port_isInstance(element: PyXmlIO.Element, error: bool = ...) -> bool: ...
def Port_isOutputPort(port: PyXmlIO.Element) -> bool: ...
def Port_setName(port: PyXmlIO.Element, newName: str): ...
def Port_setReturns(port: PyXmlIO.Element, returnName: str): ...
def Port_setSource(port: PyXmlIO.Element, sourceName: str): ...
def Port_setTags(port: PyXmlIO.Element, tags: list[str]): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import PyFnAttribute
from typing import ClassVar, Set, Tuple

class AttrTypes:
    kTypeAnyAttribute: ClassVar[int] = ...
    kTypeDoubleAttribute: ClassVar[int] = ...
    kTypeDynamic: ClassVar[int] = ...
    kTypeFloatAttribute: ClassVar[int] = ...
    kTypeGroupAttribute: ClassVar[int] = ...
    kTypeIntAttribute: ClassVar[int] = ...
    kTypeNumericAttribute: ClassVar[int] = ...
    kTypeStringAttribute: ClassVar[int] = ...
    @classmethod
    def toString(cls, value: int) -> str: ...

class OpDescription:
    def __init__(self, opType: str, descriptionAttr: PyFnAttribute.GroupAttribute) -> None: ...
    @staticmethod
    def _OpDescription__getAttrs(descriptionAttr, attrsAttrName): ...
    @staticmethod
    def _OpDescription__getChildValue(groupAttr, childName): ...
    @staticmethod
    def _OpDescription__getOpArgs(descriptionAttr): ...
    @staticmethod
    def _OpDescription__sort(items, descriptionAttr, orderingAttrName): ...

def GenerateRstDocument() -> str: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import KatanaResources as KatanaResources
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import QT4FormWidgets.ValuePolicy
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4.FormMaster.States as States
import Utils as Utils
from QT4FormWidgets.FormWidget import FormWidget
from QT4FormWidgets.WidgetFactory import WidgetFactory
from UI4.FormMaster.FnAttributePolicy import AttributePolicy as AttributePolicy
from UI4.FormMaster.GenericAssignParameterPolicy import GenericAssignParameterPolicy as GenericAssignParameterPolicy
from UI4.FormMaster.ScalarParameterPolicy import ScalarParameterPolicy as ScalarParameterPolicy
from UI4.Widgets.IconLabelFrame import IconLabelFrame as IconLabelFrame
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class BaseRampFormWidget(FormWidget):
    DefaultInterpolator: ClassVar[str] = ...
    Interpolators: ClassVar[dict] = ...
    ValuesTypeString: ClassVar[None] = ...
    _BaseRampFormWidget__InterpolatorPolicyKey: ClassVar[str] = ...
    _BaseRampFormWidget__PositionsPolicyKey: ClassVar[str] = ...
    _BaseRampFormWidget__RampSizePolicyKey: ClassVar[str] = ...
    _BaseRampFormWidget__ValuesPolicyKey: ClassVar[str] = ...
    _InterpolatorPolicyNameSuffix: ClassVar[str] = ...
    _InterpolatorPolicyNameWidgetHint: ClassVar[str] = ...
    _PositionsPolicyNameSuffix: ClassVar[str] = ...
    _PositionsPolicyNameWidgetHint: ClassVar[str] = ...
    _RampSizeParameterName: ClassVar[str] = ...
    def __init__(self, tupleSize: int, parent: PyQt5.QtWidgets.QWidget | None, policy: QT4FormWidgets.AbstractValuePolicy, factory: WidgetFactory) -> None: ...
    def _BaseRampFormWidget__companionPolicyChanged(self, valuePolicyEvent: QT4FormWidgets.ValuePolicy.ValuePolicyEvent): ...
    def _BaseRampFormWidget__getInterpolator(self) -> str: ...
    def _BaseRampFormWidget__getInterpolatorOptions(self) -> list[str]: ...
    def _BaseRampFormWidget__getKnots(self) -> list[tuple]: ...
    @classmethod
    def _BaseRampFormWidget__getPolicyPathDict(cls, mainPolicy, alteredPolicyName: Incomplete | None = ...): ...
    def _BaseRampFormWidget__setInterpolator(self, interpolator: str): ...
    def _BaseRampFormWidget__setKnots(self, knots: list[tuple]): ...
    def _addControlWidgets(self, knots: list[tuple], interpolator: str, interpolatorOptions: list[str], layout: PyQt5.QtWidgets.QHBoxLayout): ...
    def _addInterpolatorActions(self, menu: PyQt5.QtWidgets.QMenu): ...
    def _buildControlWidget(self, layout: PyQt5.QtWidgets.QHBoxLayout): ...
    def _freeze(self): ...
    def _thaw(self): ...
    def _updateControlWidgets(self, knots: list[tuple], interpolator: str): ...
    def _updateRampParameters(self, knots: list[tuple], interpolator: str): ...
    @classmethod
    def getCoPolicyPathDict(cls, policy, alteredPolicyName: Incomplete | None = ...): ...
    def valueChangedEvent(self, valuePolicyEvent: QT4FormWidgets.ValuePolicy.ValuePolicyEvent): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI
import PyFnGeolib
import typing
from typing import Set, Tuple

class OpCacheManager:
    def __init__(self, eventHandlerRegistrationFunction: typing.Callable, nodegraphEvents: set | typing.Iterable) -> None: ...
    def _OpCacheManager__on_nodegraphChangedEvent(self, eventName, eventId, **kwargs): ...
    def getOp(self, node: NodegraphAPI.Node, graphState: NodegraphAPI.GraphState, portIndex): ...
    def storeOp(self, node: NodegraphAPI.Node, graphState: NodegraphAPI.GraphState, portIndex: int, op: PyFnGeolib.GeolibRuntimeOp): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from UI4.Util.AbstractSyntaxHighlighter import AbstractSyntaxHighlighter as AbstractSyntaxHighlighter
from typing import Set, Tuple

class LuaSyntaxHighlighter(AbstractSyntaxHighlighter):
    def _createCustomBlocks(self): ...
    def _createFormats(self): ...
    def _createPostBlockRules(self): ...
    def _createRules(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Nodes2DAPI as Nodes2DAPI
import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class ViewCheckboxPopup(PyQt5.QtWidgets.QFrame):
    _ViewCheckboxPopup__ICON_NAME_CHECKED: ClassVar[str] = ...
    _ViewCheckboxPopup__ICON_NAME_UNCHECKED: ClassVar[str] = ...
    _ViewCheckboxPopup__popups: ClassVar[dict] = ...
    closed: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, valuePolicy) -> None: ...
    def _ViewCheckboxPopup__allToggled(self, on): ...
    def _ViewCheckboxPopup__anyToggled(self, on): ...
    def _ViewCheckboxPopup__updateState(self, vpEvent: Incomplete | None = ...): ...
    def closeEvent(self, ev): ...

def GetActiveViewDescription(viewMask, richText: bool = ...): ...
def QColorFromView(viewName): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import NodegraphAPI as NodegraphAPI
import PyFnAttribute
import collections
import enum
import typing
from Nodes3DAPI_cmodule import BuildAttrListFromDynamicParameterGroup as BuildAttrListFromDynamicParameterGroup, BuildGroupAttrFromParam as BuildGroupAttrFromParam
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class LayoutAttributesMixin:
    def __init__(self) -> None: ...
    def _LayoutAttributesMixin__generateLayoutAttributes(self, nodeNames, graphState: NodegraphAPI.GraphState): ...
    def _getExcludedNodes(self): ...
    def _isLayoutAttributesValid(self): ...
    def getContentsLayoutAttributes(self, nodeNames: Incomplete | None = ..., graphState: typing.Optional[NodegraphAPI.GraphState] = ...) -> NodegraphAPI.PyFnAttribute.GroupAttribute: ...
    def invalidateLayout(self): ...
    def polish(self): ...

class NodeType(enum.Enum):
    Backdrop: ClassVar[NodeType] = ...
    DotNode: ClassVar[NodeType] = ...
    NetworkMaterial: ClassVar[NodeType] = ...
    Other: ClassVar[NodeType] = ...
    ShadingGroup: ClassVar[NodeType] = ...
    ShadingNode: ClassVar[NodeType] = ...
    ShadingNodeArrayConnector: ClassVar[NodeType] = ...
    Switch: ClassVar[NodeType] = ...
    VariableSwitch: ClassVar[NodeType] = ...
    _member_map_: ClassVar[collections.OrderedDict] = ...
    _member_names_: ClassVar[list] = ...
    _member_type_: ClassVar[type[object]] = ...
    _value2member_map_: ClassVar[dict] = ...
    @classmethod
    def __init__(cls, value) -> None: ...
    def _generate_next_value_(self, name, start, count, last_values): ...

class _LayoutAttributesFactory:
    def __init__(self, nodeNames: dict[NodegraphAPI.Node, str], graphState: NodegraphAPI.GraphState) -> None: ...
    def _LayoutAttributesFactory__generateConnectionStringAttr(self, ports): ...
    @staticmethod
    def _LayoutAttributesFactory__getBackdropAttributes(node: NodegraphAPI.Node, nodeShapeAttrs: dict) -> PyFnAttribute.GroupAttribute: ...
    @staticmethod
    def _LayoutAttributesFactory__getDotNodeAttributes(node: NodegraphAPI.Node, nodeShapeAttrs: dict) -> PyFnAttribute.GroupAttribute: ...
    def _LayoutAttributesFactory__getNodeName(self, node: NodegraphAPI.Node): ...
    @staticmethod
    def _LayoutAttributesFactory__getNodeType(node: NodegraphAPI.Node) -> NodeType: ...
    @staticmethod
    def _LayoutAttributesFactory__getReturnPorts(node: NodegraphAPI.Node): ...
    def _LayoutAttributesFactory__getShadingGroupAttributes(self, node: NodegraphAPI.GroupNode, nodeShapeAttrs: dict) -> PyFnAttribute.GroupAttribute: ...
    @classmethod
    def _LayoutAttributesFactory__getShadingNodeArrayConnectorNodeAttributes(cls, node: NodegraphAPI.Node, _nodeShapeAttrs: dict) -> PyFnAttribute.GroupAttribute: ...
    def _LayoutAttributesFactory__getShadingNodeAttributes(self, node: NodegraphAPI.Node, nodeShapeAttrs: dict) -> PyFnAttribute.GroupAttribute: ...
    @classmethod
    def _LayoutAttributesFactory__getSwitchNodeAttributes(cls, node: NodegraphAPI.Node, _nodeShapeAttrs: dict) -> PyFnAttribute.GroupAttribute: ...
    @classmethod
    def _LayoutAttributesFactory__getVariableSwitchNodeAttributes(cls, node: NodegraphAPI.Node, _nodeShapeAttrs: dict) -> PyFnAttribute.GroupAttribute: ...
    @staticmethod
    def _LayoutAttributesFactory__writeColorAttribute(groupBuilder: PyFnAttribute.GroupBuilder, nodeShapeAttrs: dict): ...
    def _LayoutAttributesFactory__writeCommonAttributes(self, groupBuilder: PyFnAttribute.GroupBuilder, node: NodegraphAPI.Node, nodeShapeAttrs: dict): ...
    def _LayoutAttributesFactory__writeConnectionsAttribute(self, groupBuilder: PyFnAttribute.GroupAttributes, node: NodegraphAPI.Node): ...
    @staticmethod
    def _LayoutAttributesFactory__writeInputPorts(groupBuilder: PyFnAttribute.GroupBuilder, node: NodegraphAPI.Node): ...
    def _LayoutAttributesFactory__writeNodeParameters(self, groupBuilder, node: NodegraphAPI.Node): ...
    def _LayoutAttributesFactory__writeNodeShapeAttributes(self, groupBuilder, node: NodegraphAPI.Node): ...
    @staticmethod
    def _LayoutAttributesFactory__writePagesAttribute(groupBuilder: PyFnAttribute.GroupAttributes, attrsDict: dict): ...
    @staticmethod
    def _LayoutAttributesFactory__writePublicInterfaceConfigParams(groupBuilder: PyFnAttribute.GroupBuilder, node: NodegraphAPI.Node): ...
    @staticmethod
    def _LayoutAttributesFactory__writeShadingGroupInputPorts(groupBuilder, node: NodegraphAPI.Node): ...
    def _LayoutAttributesFactory__writeShadingGroupReturnConnections(self, groupBuilder, node: NodegraphAPI.Node): ...
    @staticmethod
    def _LayoutAttributesFactory__writeShadingGroupReturnPorts(groupBuilder, node: NodegraphAPI.Node): ...
    @classmethod
    def _LayoutAttributesFactory__writeSidebarAttributes(cls, groupBuilder: PyFnAttribute.GroupBuilder, barName: str, nodeShapeAttrs: dict): ...
    def _LayoutAttributesFactory__writeUserParameters(self, groupBuilder, node: NodegraphAPI.Node): ...
    @classmethod
    def _LayoutAttributesFactory__writeUserParametersGroup(cls, groupBuilder, node: NodegraphAPI.Node, parameter, graphState: NodegraphAPI.GraphState): ...
    @staticmethod
    def _LayoutAttributesFactory__writeViewState(groupBuilder: PyFnAttribute.GroupBuilder, nodeShapeAttrs: dict): ...
    def build(self, node: NodegraphAPI.Node) -> PyFnAttribute.GroupAttribute: ...

def GetContentsLayoutAttributes(node: NodegraphAPI.GroupNode, excludedNodes: Incomplete | None = ...) -> PyFnAttribute.GroupAttribute: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtGui
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
from QT4FormWidgets.PopupFormWidget import PopupFormWidget
from QT4FormWidgets.WidgetFactory import WidgetFactory
from typing import Set, Tuple

class AttributeTypeEditor(PopupFormWidget):
    def __init__(self, parent: PyQt5.QtWidgets.QWidget | None, policy: QT4FormWidgets.AbstractValuePolicy, factory: WidgetFactory) -> None: ...
    def dragEnterEvent(self, event: PyQt5.QtGui.QDragEnterEvent): ...
    def dropEvent(self, event: PyQt5.QtGui.QDropEvent): ...
    def setLocked(self, value: bool, checkLockOps: bool = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI.NodeExtensions as NodeExtensions
import NodegraphAPI_cmodule
import NodegraphAPI.NodegraphGlobals as NodegraphGlobals
from NodegraphAPI_cmodule import PythonNode as PythonNode, node_registerPythonNodeType as node_registerPythonNodeType
from typing import Set, Tuple

class RenderScriptNode(NodegraphAPI_cmodule.PythonNode):
    def __init__(self) -> None: ...
    def addParameterHints(self, attrName, inputDict): ...
    def getOutlineOutputInfo(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import PyFnGeolibServices as FnGeolibServices
import GeolibRuntime
import NodegraphAPI
import PyUtilModule.RenderManager.RenderGlobals as RenderGlobals
import RenderingAPI as RenderingAPI
import PyUtilModule.RenderingCommon as RenderingCommon
import PyResolutionTableFn as ResolutionTable
from typing import Set, Tuple

def AddCameraOverrideToRecipe(txn, inputOp, cameraLocationPath): ...
def AddRenderOutputsToRecipe(txn: GeolibRuntime.Transaction, op: GeolibRuntime.Op, outputs: list) -> GeolibRuntime.Op: ...
def AddRenderSettingsToRecipe(txn, renderOp, graphState: NodegraphAPI.GraphState, renderSettingsAttr): ...
def AddVirtualCameraToRecipe(txn, inputOp, cameraLocationPath): ...
def BakeAOVs(txn: GeolibRuntimeTransaction, mainSequenceID: int, op: GeolibRuntimeOp) -> GeolibRuntime.Op: ...
def GetInteractiveOutputs(client: GeolibRuntime.Client) -> list[str]: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore as QtCore
from typing import Set, Tuple

def GetBrowserSettings(): ...
def LoadFrameGeometry(widget, group): ...
def SaveFrameGeometry(widget, group): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
from typing import ClassVar, Set, Tuple

_moduleInitialized: bool
_platformKind: int

class PlatformKind:
    LINUX: ClassVar[int] = ...
    MAC: ClassVar[int] = ...
    UNKNOWN: ClassVar[int] = ...
    WINDOWS: ClassVar[int] = ...

def GetKatanaTempfile(prefix: str, suffix: str, maxInt: int = ...) -> str: ...
def GetPlatformKind() -> PlatformKind: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from QT4FormWidgets.ArrayFormWidget import ArrayFormWidget as ArrayFormWidget
from QT4FormWidgets.CapsuleFormWidget import CapsuleFormWidget as CapsuleFormWidget
from QT4FormWidgets.CheckBoxFormWidget import CheckBoxFormWidget as CheckBoxFormWidget
from QT4FormWidgets.FormWidget import FormWidget as FormWidget
from QT4FormWidgets.GroupFormWidget import GroupFormWidget as GroupFormWidget
from QT4FormWidgets.MenuGroupFormWidget import MenuGroupFormWidget as MenuGroupFormWidget
from QT4FormWidgets.MultiFormWidget import MultiFormWidget as MultiFormWidget
from QT4FormWidgets.NullFormWidget import NullFormWidget as NullFormWidget
from QT4FormWidgets.NumberFormWidget import NumberFormWidget as NumberFormWidget
from QT4FormWidgets.PopupFormWidget import BooleanFormWidget as BooleanFormWidget, MappingPopupFormWidget as MappingPopupFormWidget, PopupFormWidget as PopupFormWidget
from QT4FormWidgets.StringFormWidget import StringFormWidget as StringFormWidget
from QT4FormWidgets.TabGroupFormWidget import TabGroupFormWidget as TabGroupFormWidget
from QT4FormWidgets.TextFormWidget import TextFormWidget as TextFormWidget
from typing import Set, Tuple

class WidgetFactory:
    def __init__(self) -> None: ...
    def _getWidgetClass(self, policy, hints): ...
    def buildWidget(self, parent, policy): ...
    def registerWidgetType(self, name, cls): ...

def GetDefaultWidgetFactory(): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import DrawingModule as DrawingModule
import NodegraphAPI as NodegraphAPI
import QT4GLLayerStack as QT4GLLayerStack
import QT4GLLayerStack.LayerStack
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import Utils as Utils
from UI4.Tabs.NodeGraphTab.Layers.LinkConnectionLayer import LinkConnectionLayer as LinkConnectionLayer
from typing import Set, Tuple

class LinkInteractionLayer(QT4GLLayerStack.LayerStack.Layer):
    def __init__(self, *args, **kwargs) -> None: ...
    def _LinkInteractionLayer__node_delete_cb(self, eventType, eventID, node: NodegraphAPI.Node, *args, **kwargs): ...
    def paintGL(self): ...
    def processEvent(self, event): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Util.IconManager as IconManager
from UI4.Widgets.ToolbarButton import ToolbarButton as ToolbarButton
from typing import Set, Tuple

class AddTabButton(ToolbarButton):
    def __init__(self, parent, frame) -> None: ...

class CloseAllTabsButton(ToolbarButton):
    def __init__(self, parent, frame) -> None: ...
    def _CloseAllTabsButton__on_clicked(self): ...

class CloseTabButton(ToolbarButton):
    def __init__(self, parent, frame) -> None: ...
    def _CloseTabButton__on_clicked(self): ...

class MaximizePaneButton(ToolbarButton):
    def __init__(self, parent, frame) -> None: ...
    def _MaximizePaneButton__on_clicked(self): ...
    def _MaximizePaneButton__on_frame_frameMaximized(self, state): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import NodegraphAPI as NodegraphAPI
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
from PyUtilModule.VirtualKatana import FormMaster as FormMaster
from UI4.Tabs.BaseTab import BaseTab as BaseTab
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

NodeTypes: list
PluginRegistry: list
nodeType: str
nodeTypesValue: str

class CustomNodeTypeTab(NodeTypeTab):
    NodeType: ClassVar[str] = ...

class NodeTypePanel(NodeTypeTab): ...

class NodeTypeTab(BaseTab):
    def __init__(self, parent) -> None: ...
    def _NodeTypeTab__on_combobox_activated(self, text): ...
    def doNodesChanged(self, args: Incomplete | None = ...): ...
    def hideEvent(self, event): ...
    def registerHandlers(self, state): ...
    def showEvent(self, event): ...

class ScrollingParameters(PyQt5.QtWidgets.QScrollArea):
    def __init__(self, parent, param) -> None: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import PyFnAttribute
import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyUtilModule.WorkingSet
import PyQt5.QtCore as QtCore
import UI4.Widgets.SceneGraphView.Bridge
from PyUtilModule.WorkingSet import WorkingSet
from PyUtilModule.WorkingSetManager import WorkingSetManager as WorkingSetManager
from UI4.Util.WorkingSets import IncludeProxyChildrenInWorkingSet as IncludeProxyChildrenInWorkingSet
from UI4.Widgets.SceneGraphView.ColumnDataType import RegisterDataType as RegisterDataType
from UI4.Widgets.SceneGraphView.ItemDelegates.StateItemDelegate import StateItemDelegate as StateItemDelegate
from UI4.Widgets.WorkingSetWidgets import WorkingSetContextMenu as WorkingSetContextMenu, WorkingSetIconManager as WorkingSetIconManager, WorkingSetResetStateAction as WorkingSetResetStateAction
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class WorkingSetItemDelegate(StateItemDelegate):
    FixedColumnWidth: ClassVar[int] = ...
    WorkingSetName: ClassVar[str] = ...
    WorkingSetStateAttributeName: ClassVar[str] = ...
    def __init__(self, bridge: Bridge[UI4.Widgets.SceneGraphView.Bridge.Bridge], treeWidget: PyQt5.QtWidgets.QTreeWidget, parent: Incomplete | None = ..., workingSetName: Incomplete | None = ...) -> None: ...
    def _WorkingSetItemDelegate__locationStateChangedCallback(self, locationStateChanges: list[str, int, int], workingSet: WorkingSet, sender: object): ...
    def _WorkingSetItemDelegate__on_treeWidget_destroyed(self): ...
    def _WorkingSetItemDelegate__updateTerminalOps(self): ...
    def calculateItemState(self, option: QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex) -> PyUtilModule.WorkingSet.WorkingSet.State | None: ...
    def createContextMenu(self, index: PyQt5.QtCore.QModelIndex, selectedItems: list[PyQt5.QtWidgets.QTreeWidgetItem]) -> PyQt5.QtWidgets.QMenu | None: ...
    def customizeColumnTitleContextMenu(self, menu: PyQt5.QtWidgets.QMenu): ...
    def getTerminalOps(self) -> list[tuple[str, PyFnAttribute.GroupAttribute, str] | Tuple[str, PyFnAttribute.GroupAttribute] | str]: ...
    @classmethod
    def isPropertyValid(cls, propertyName: str) -> bool: ...
    def modifyItemState(self, item: PyQt5.QtWidgets.QTreeWidgetItem, index: PyQt5.QtCore.QModelIndex, event: PyQt5.QtGui.QMouseEvent) -> bool: ...
    def setProperty(self, propertyName: str, propertyValue: object | None): ...
    def setWorkingSetName(self, workingSetName: str): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Widgets.SceneGraphView.SceneGraphViewColumn
import typing
from UI4.Widgets.SceneGraphView.ColumnDataType import ColumnDataType as ColumnDataType
from UI4.Widgets.SceneGraphView.SceneGraphViewColumn import SceneGraphColumn as SceneGraphColumn, SceneGraphColumnSet as SceneGraphColumnSet
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class SceneGraphTabColumn(UI4.Widgets.SceneGraphView.SceneGraphViewColumn.SceneGraphColumn):
    DefaultAttributeScope: ClassVar[str] = ...
    def __init__(self, columnName: str = ..., columnChangedCallback: typing.Optional[typing.Callable] = ..., parentSet: Incomplete | None = ...) -> None: ...
    def getAttributeScope(self) -> str | None: ...
    def getDefaultDisplay(self) -> str | None: ...
    def getPreferenceAttributeName(self) -> str | None: ...
    def setAttributeScope(self, attributeScope: str): ...
    def setDefaultDisplay(self, defaultDisplay: str): ...
    def setFromPrefs(self, visible: bool = ..., attributeName: Incomplete | None = ..., attributeScope: Incomplete | None = ..., defaultDisplay: Incomplete | None = ...): ...
    def setPreferenceAttributeName(self, attributeName: str): ...

class SceneGraphTabColumnSet(UI4.Widgets.SceneGraphView.SceneGraphViewColumn.SceneGraphColumnSet):
    DefaultColumnWidth: ClassVar[int] = ...
    def __init__(self, setName: str = ..., columnChangedCallback: typing.Optional[typing.Callable] = ..., parentSet: Incomplete | None = ...) -> None: ...
    def addColumnFromPrefs(self, visible: bool = ..., attributeName: Incomplete | None = ..., attributeScope: Incomplete | None = ..., defaultDisplay: Incomplete | None = ..., displayType: Incomplete | None = ...) -> SceneGraphTabColumn | None: ...
    def setColumnsFromPrefs(self, prefsArray: list[tuple]): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Nodes3DAPI.DynamicParameterUtil as DynamicParameterUtil
import PyFnAttribute as FnAttribute
import PyFnGeolib as FnGeolib
import PyFnGeolibServices as FnGeolibServices
import PyUtilModule.Hints as Hints
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI as Nodes3DAPI
import Nodes3DAPI_cmodule as Nodes3DAPI_cmodule
import RenderingAPI.RenderPlugins as RenderPlugins
import RenderingAPI_cmodule.RendererInfo as RendererInfo
import RenderingAPI as RenderingAPI
import NodegraphAPI.StructuredPorts as StructuredPorts
import Utils as Utils
import typing
from Nodes3DAPI.Node3D import Node3D as Node3D
from Nodes3DAPI.ShadingNodeUtil import GetConnectionNames as GetConnectionNames, ReportError as ReportError
from Nodes3DAPI_cmodule import BuildAttrListFromDynamicParameterGroup as BuildAttrListFromDynamicParameterGroup
from _typeshed import Incomplete
from typing import Set, Tuple

class ShadingNodeBase(Node3D):
    def __init__(self) -> None: ...
    def _ShadingNodeBase__buildOpArgs(self, graphState: NodegraphAPI.GraphState, inputNames, parentInputs, paramTracker): ...
    def _ShadingNodeBase__checkDynamicParametersInternal(self, paramsAttr, interfaceAttr, dynamicArrayAttrNames, getHintsFunction): ...
    def _ShadingNodeBase__getUpstreamMaterialParameterDefaultsOp(self, transaction, graphState: NodegraphAPI.GraphState, locationPath): ...
    def _ShadingNodeBase__on_parameter_setValue(self, eventName: str, eventId: str, param: Incomplete | None = ..., node: typing.Optional[NodegraphAPI.Node] = ..., **_kwargs): ...
    def _ShadingNodeBase__on_shadingNodeCreate(self, _eventName, _eventID, **_kwargs): ...
    def _ShadingNodeBase__setLeafAttrsInAttributeSet(self, sourceAttr, targetAttrPath, paramPath, opArgsGb, frameTime): ...
    def _assignPortIndexes(self): ...
    def _buildCoshaderInputPorts(self, hintDict): ...
    def _buildInputPorts(self, rendererInfoPlugin, hintDict, shader): ...
    def _buildOutputPorts(self, rendererInfoPlugin, hintDict, shader): ...
    def _buildPorts(self, shader, rendererInfoPlugin, inputsHintDict, outputsHintDict): ...
    def _cleanAllPorts(self, whitelist): ...
    def _getIncomingSceneOpAndLocation(self, port: NodegraphAPI.Port, graphState: NodegraphAPI.GraphState, transaction): ...
    def _getOp(self, port: NodegraphAPI.Port, graphState: NodegraphAPI.GraphState, visitedState, transaction): ...
    def _getShaderAttrKeys(self): ...
    def _getShadingNodeConnectionInfo(self, sourcePortName: str) -> tuple[str, str, bool]: ...
    def _getStaticAttrHintsForIncomingSceneQuery(self, attrPath): ...
    def _getUpdateParametersSupportedKeywords(self): ...
    def _updateCoshaderPortVisibility(self, hintDict: dict): ...
    def _updateParameters(self, groupAttr, force: bool = ..., defaultAttr: Incomplete | None = ..., getHintsFunction: Incomplete | None = ...): ...
    def _validateExistingPortConnections(self, port: NodegraphAPI.Port): ...
    def addInputPort(self, portName, label: Incomplete | None = ..., page: Incomplete | None = ..., hide: bool = ..., color: Incomplete | None = ...): ...
    def addOutputPort(self, portName): ...
    def addParameterHints(self, attrName, inputDict): ...
    def allowMismatchedConnection(self, myPort, incomingPort): ...
    def checkDynamicParameters(self, *args, **kwds): ...
    def clearParamHistory(self): ...
    def getAdjustedName(self, inputName, frameTime): ...
    def getAdjustedPageName(self, inputPage, frameTime): ...
    def getInfoString(self): ...
    def getOutputTags(self, outputName): ...
    def getRendererName(self) -> str: ...
    def setShowHiddenParameters(self, showHidden: bool): ...
    def showHiddenParameters(self) -> bool: ...
    def validateConnection(self, otherOutPort, myInPort, errorMessages: Incomplete | None = ...): ...

def AssignNodePortColors(nodes: Incomplete | None = ...): ...
def GetPortColor(hintsDict: Incomplete | None = ..., **kwargs) -> list: ...
def GetRegisteredNodeTypes(): ...
def InitializeShadingNode(nodeName, shadingNode, rendererInfoPluginName): ...
def RetargetExtraHints(nodeTypeName): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import UI4.Widgets.ProductSaveWidgets
from typing import Set, Tuple

class CatalogSaveDialog(UI4.Widgets.ProductSaveWidgets.ProductOrFileSaveDialog):
    def __init__(self, parent, options) -> None: ...
    def _CatalogSaveDialog__colorspace_activated_CB(self, *args): ...
    def _CatalogSaveDialog__imageExtension_activated_CB(self, *args): ...
    def addButtonsToLayout(self): ...
    def getResult(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4.Widgets.SceneGraphView.SceneGraphViewIconManager as SceneGraphViewIconManager
import UI4
import Utils as Utils
import typing
from UI4.Widgets.SceneGraphView.ColumnDataType import ColumnDataType as ColumnDataType
from Utils.Decorators import deprecated as deprecated
from _typeshed import Incomplete
from typing import Any, ClassVar, Set, Tuple

class BaseSceneGraphColumn:
    def __init__(self, name: str = ..., columnChangedCallback: typing.Optional[typing.Callable] = ..., parentSet: Incomplete | None = ...) -> None: ...
    def callColumnChangedCallback(self): ...
    def getColumnChangedCallback(self) -> typing.Callable | None: ...
    def getIndex(self) -> int: ...
    def getName(self) -> str: ...
    def getParentSet(self) -> SceneGraphColumnSet[SceneGraphColumnSet] | None: ...
    def getParentSetNames(self) -> list[str]: ...
    def getParentSets(self) -> list[SceneGraphColumnSet[SceneGraphColumnSet]]: ...
    def isVisible(self) -> bool: ...
    def setColumnChangedCallback(self, callback: typing.Callable | None): ...
    def setIndex(self, index: int): ...
    def setName(self, name: str): ...
    def setParentSet(self, parentSet: SceneGraphColumnSet[SceneGraphColumnSet] | None): ...
    def setVisible(self, visible: bool): ...

class SceneGraphColumn(BaseSceneGraphColumn):
    def __init__(self, columnName: str = ..., columnChangedCallback: typing.Optional[typing.Callable] = ..., parentSet: Incomplete | None = ...) -> None: ...
    def getAttributeName(self) -> str | None: ...
    def getAttributeNames(self) -> list[str]: ...
    @classmethod
    def getColorDisplayTypeName(cls) -> str: ...
    def getDataType(self) -> int: ...
    @classmethod
    def getDefaultDisplayTypeIndex(cls) -> int: ...
    @classmethod
    def getDefaultDisplayTypeName(cls) -> str: ...
    def getFixedWidth(self) -> int | None: ...
    def getLookFileMaterialAssignmentCallback(self) -> typing.Callable | None: ...
    def getMasterMaterialCallbacks(self): ...
    def getMaximumWidth(self) -> int | None: ...
    def getMinimumWidth(self) -> int | None: ...
    def getProperties(self) -> list[tuple[str, Any]]: ...
    @classmethod
    def getSupportedDisplayTypes(cls) -> list[str]: ...
    def getTemplateMaterialCallbacks(self) -> tuple[typing.Callable, ...] | None: ...
    def getTitle(self) -> SceneGraphColumnTitle[SceneGraphColumnTitle]: ...
    def getTitleClickStyle(self) -> str: ...
    def getTitleClickedCallback(self) -> typing.Callable | None: ...
    def getTitleIcon(self) -> PyQt5.QtGui.QIcon | None: ...
    def getTitleIconName(self) -> str: ...
    def getTitleStyle(self) -> str: ...
    def getTitleText(self) -> str: ...
    def getTitleToolTip(self) -> str: ...
    def getWidth(self) -> int: ...
    def isEditable(self) -> bool: ...
    def isLocationName(self) -> bool: ...
    def isTitleToggledOn(self) -> bool: ...
    def isValueComparisonEnabled(self) -> bool: ...
    def setAttributeName(self, attributeName: str, callCallback: bool = ...): ...
    def setAttributeNames(self, attributeNames: list[str]): ...
    def setDataType(self, dataType: cls): ...
    def setEditable(self, editable: bool): ...
    def setFixedWidth(self, fixedWidth: int | None): ...
    def setIsLocationName(self, isLocationName: bool): ...
    def setLookFileMaterialCallback(self, lookFileMaterialAssignmentCallback: typing.Callable | None): ...
    def setMasterMaterialCallbacks(self, masterMaterialsRequestCallback: typing.Callable, masterMaterialAssignmentCallback: typing.Callable): ...
    def setMaximumWidth(self, maximumWidth: int | None): ...
    def setMinimumWidth(self, minimumWidth: int | None): ...
    def setProperty(self, propertyName: str, propertyValue: object | None): ...
    def setTemplateMaterialCallbacks(self, templateMaterialsRequestCallback: typing.Callable | None, templateMaterialAssignmentCallback: typing.Callable | None): ...
    def setTitleClickStyle(self, titleClickStyle: str): ...
    def setTitleClickedCallback(self, callback: typing.Callable | None): ...
    def setTitleIcon(self, icon: PyQt5.QtGui.QIcon | None): ...
    def setTitleIconName(self, titleIconName: str): ...
    def setTitleStyle(self, titleStyle: str): ...
    def setTitleText(self, titleText: str): ...
    def setTitleToggledOn(self, titleToggledOn: bool): ...
    def setTitleToolTip(self, toolTip: str): ...
    def setValueComparisonEnabled(self, valueComparisonEnabled: bool): ...
    def setWidth(self, width: int): ...
    def titleClicked(self, columnTitleRect: PyQt5.QtCore.QRect): ...

class SceneGraphColumnSet(BaseSceneGraphColumn):
    _SceneGraphColumnSet__MAX_SET_NESTING_DEPTH: ClassVar[int] = ...
    def __init__(self, setName: str = ..., columnChangedCallback: typing.Optional[typing.Callable] = ..., parentSet: Incomplete | None = ..., columnPresetManager: Incomplete | None = ...) -> None: ...
    def _SceneGraphColumnSet__applyColumnSettings(self, settings: dict, setMethod: typing.Callable, depth: int = ...): ...
    @staticmethod
    def _SceneGraphColumnSet__checkRecursionDepth(depth: int): ...
    def _SceneGraphColumnSet__getChildByName(self, childName: str, childType: type, depth: int = ...) -> BaseSceneGraphColumn[BaseSceneGraphColumn] | None: ...
    def _SceneGraphColumnSet__getColumnByIndex(self, columnIndex: int, visibleOnly: bool, depth: int = ...) -> BaseSceneGraphColumn[BaseSceneGraphColumn] | None: ...
    def _SceneGraphColumnSet__getColumnSettings(self, settings: dict, getMethod: typing.Callable, depth: int = ...): ...
    def addChild(self, child: BaseSceneGraphColumn[BaseSceneGraphColumn], resetParentSet: bool = ...): ...
    def addColumn(self, columnName: str) -> SceneGraphColumn[SceneGraphColumn]: ...
    def addColumnSet(self, setName: str = ...) -> SceneGraphColumnSet[SceneGraphColumnSet]: ...
    def addKeyboardShortcut(self, shortcut: str | None | int | QKeySequence): ...
    def applyColumnVisibilitySettings(self, columnVisibilitySettings: dict): ...
    def clearChildren(self): ...
    def getAttributeName(self, columnIndex: int, visibleOnly: bool = ...) -> str | None: ...
    def getAttributeNames(self, columnIndex: int, visibleOnly: bool = ...) -> list[str]: ...
    def getChildByName(self, childName: str) -> Tuple[SceneGraphColumn[SceneGraphColumn], SceneGraphColumnSet[SceneGraphColumnSet] | None]: ...
    def getChildIndex(self, child: BaseSceneGraphColumn[BaseSceneGraphColumn]) -> int: ...
    def getColumnByIndex(self, columnIndex: int, visibleOnly: bool = ...) -> BaseSceneGraphColumn[BaseSceneGraphColumn]: ...
    def getColumnByName(self, columnName: str) -> BaseSceneGraphColumn[BaseSceneGraphColumn] | None: ...
    def getColumnCount(self, visibleOnly: bool = ...) -> int: ...
    def getColumnSetByName(self, columnSetName: str) -> SceneGraphColumnSet[SceneGraphColumnSet] | None: ...
    def getColumnVisibilitySettings(self) -> dict: ...
    def getColumns(self, visibleOnly: bool = ...) -> list[BaseSceneGraphColumn[BaseSceneGraphColumn]]: ...
    def getDataType(self, columnIndex: int, visibleOnly: bool = ...) -> int | None: ...
    def getNames(self, visibleOnly: bool = ...) -> list[str]: ...
    def getTitleText(self, columnIndex: int, visibleOnly: bool = ...) -> str | None: ...
    def getTitles(self, visibleOnly: bool = ...) -> list[SceneGraphColumnTitle[UI4.SceneGraphView.SceneGraphViewColumn.SceneGraphColumnTitle]]: ...
    def getWidth(self, columnIndex: int, visibleOnly: bool = ...) -> int | None: ...
    def getWidths(self, visibleOnly: bool = ...) -> list[int]: ...
    def isEditable(self, columnIndex: int, visibleOnly: bool = ...) -> bool | None: ...
    def isLocationNameColumn(self, columnIndex: int, visibleOnly: bool = ...) -> bool | None: ...
    def removeChild(self, child: BaseSceneGraphColumn[BaseSceneGraphColumn], resetParentSet: bool = ...): ...
    def removeKeyboardShortcut(self, shortcut: str | None | int | QKeySequence): ...
    def removeKeyboardShortcuts(self): ...
    def setChildIndex(self, child: BaseSceneGraphColumn[BaseSceneGraphColumn], index: int): ...
    def setColumnChangedCallback(self, callback: typing.Callable | None): ...

class SceneGraphColumnTitle:
    class ClickStyles:
        All: ClassVar[list] = ...
        MenuIndicator: ClassVar[str] = ...
        Toggle: ClassVar[str] = ...
    DisplayStyles: ClassVar[list] = ...
    IconOnly: ClassVar[str] = ...
    TextAndIcon: ClassVar[str] = ...
    TextOnly: ClassVar[str] = ...
    def __init__(self, text: str, iconName: str, style: str) -> None: ...
    def _SceneGraphColumnTitle__shouldShowIcon(self) -> bool: ...
    def _SceneGraphColumnTitle__shouldShowText(self) -> bool: ...
    def callClickedCallback(self, columnTitleRect: PyQt5.QtCore.QRect): ...
    def getClickStyle(self) -> str: ...
    def getClickedCallback(self) -> typing.Callable | None: ...
    def getIcon(self) -> PyQt5.QtGui.QIcon | None: ...
    def getIconName(self) -> str: ...
    def getStyle(self) -> str: ...
    def getText(self) -> str: ...
    def getToolTip(self) -> str: ...
    def isToggledOn(self) -> bool: ...
    def setClickStyle(self, clickStyle: str): ...
    def setClickedCallback(self, callback: typing.Callable | None): ...
    def setIcon(self, icon: PyQt5.QtGui.QIcon | None): ...
    def setIconName(self, iconName: str): ...
    def setStyle(self, style: str): ...
    def setText(self, text: str): ...
    def setToggledOn(self, toggledOn: bool): ...
    def setToolTip(self, toolTip: str): ...
    def setUpdateFunction(self, updateFunction: typing.Callable | None, *args): ...

def GetNonInformationalAttributeName(attributeNames: list[str]) -> str | None: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import DrawingModule as DrawingModule
import NodegraphAPI as NodegraphAPI
import PyQt5.QtCore
import QT4GLLayerStack as QT4GLLayerStack
import QT4GLLayerStack.LayerStack
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import NodegraphAPI.StructuredPorts as StructuredPorts
import UI4 as UI4
import Utils as Utils
from PyUtilModule.VirtualKatana import Widgets as Widgets
from UI4.Tabs.NodeGraphTab.Layers.StructuredPortsNodeLinkConnectionLayer import StructuredPortsNodeLinkConnectionLayer as StructuredPortsNodeLinkConnectionLayer
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class StructuredPortsNodeInteractionLayer(QT4GLLayerStack.LayerStack.Layer):
    class PortMenuEntry:
        def __init__(self, port: NodegraphAPI.Port, children) -> None: ...
    PORT_CONNECTION_COLUMN: ClassVar[int] = ...
    PORT_NAME_COLUMN: ClassVar[int] = ...
    _StructuredPortsNodeInteractionLayer__pixmaps: ClassVar[dict] = ...
    linkConnectionPortChosen: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    linkMenuItemChosen: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, *args, **kwargs) -> None: ...
    def _StructuredPortsNodeInteractionLayer__linkMenuItemChosen(self, item, meta, nodeName): ...
    def _StructuredPortsNodeInteractionLayer__node_delete_cb(self, eventType, eventID, node: NodegraphAPI.Node, *args, **kwargs): ...
    def _StructuredPortsNodeInteractionLayer__on_menuPopup_show(self): ...
    def _StructuredPortsNodeInteractionLayer__portMenuItemChosen(self, item, meta): ...
    def _StructuredPortsNodeInteractionLayer__processMouseMove(self, event): ...
    def _StructuredPortsNodeInteractionLayer__processMousePress(self, event): ...
    def _StructuredPortsNodeInteractionLayer__showHiddenPortsCallback(self, value, name, meta): ...
    def _disablePortsMenuItem(self, item: SortableTreeWidgetItem): ...
    def _isPortConnectedToNode(self, rawPort: NodegraphAPI.Port, node: NodegraphAPI.Node): ...
    def _recursiveAddAllPortsToMenu(self, menu, ports, parentItem: Incomplete | None = ..., parentHasConnection: bool = ...): ...
    def _recursiveAddConnectedPorts(self, menu: FilterablePopupButton, portMenuEntries: list[PortMenuEntry], parentItem: Incomplete | None = ...): ...
    def _recursiveGetConnectedPorts(self, menu, ports, onlyConnectedToNode): ...
    def _setPortsMenuItemConnections(self, item: SortableTreeWidgetItem, rawPort: NodegraphAPI.Port): ...
    def _setPortsMenuItemTooltip(self, item: SortableTreeWidgetItem, rawPort: NodegraphAPI.Port): ...
    def addPortsMenuItem(self, menu: FilterablePopupButton, port: NodegraphAPI.Port, parentItem: SortableTreeWidgetItem): ...
    def fillPortMenu(self, menu, node: NodegraphAPI.Node, isInput, onlyConnectedToNode: Incomplete | None = ...): ...
    def getPortMenu(self): ...
    def paintGL(self): ...
    def processEvent(self, event): ...
    def showPortMenu(self, mousePos, node: NodegraphAPI.Node, action: Incomplete | None = ..., destinationNodeName: Incomplete | None = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import DrawingModule as DrawingModule
import NodeGraphView as NodeGraphView
import NodegraphAPI as NodegraphAPI
import UI4.KatanaPrefs.PrefNames as PrefNames
import QT4GLLayerStack as QT4GLLayerStack
import QT4GLLayerStack.LayerStack
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import UI4 as UI4
from UI4.KatanaPrefs.KatanaPrefsObject import KatanaPrefs as KatanaPrefs
from UI4.Tabs.NodeGraphTab.Layers.NodeOverlayLayer import DrawNodeNameOverlay as DrawNodeNameOverlay
from typing import Set, Tuple

class OffscreenFlagDisplayLayer(QT4GLLayerStack.LayerStack.Layer):
    def __init__(self, *args, **kwargs) -> None: ...
    def _OffscreenFlagDisplayLayer__drawArrowToNode(self, node: NodegraphAPI.Node, wsize, p1, p2, cx, cy, color, mousePos): ...
    def _OffscreenFlagDisplayLayer__hitTestArrow(self, pos, angle, clickPoint): ...
    def paintGL(self): ...
    def processEvent(self, event): ...

def _IsNodeHidden(node: NodegraphAPI.Node): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import CacheManager as CacheManager
import Callbacks as Callbacks
import ConditionalStateGrammar as ConditionalStateGrammar
import ConfigurationAPI_cmodule as Configuration
import PyFnAttribute as FnAttribute
import PyFnGeolib as FnGeolib
import PyFnGeolibProducers as FnGeolibProducers
import PyFnGeolibServices as FnGeolibServices
import GeoAPI as GeoAPI
import KatanaResources as KatanaResources
import LoggingAPI as LoggingAPI
import Naming as Naming
import Nodes3DAPI.Node3D as Node3D
import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import PyOpenColorIO as OCIO
import PyXmlIO as PyXmlIO
import RenderingAPI as RenderingAPI
import PyResolutionTableFn as ResolutionTable
import Naming as SafeIdentifier
import PyUtilModule.ScenegraphUtils as ScenegraphUtils
import Naming as UniqueName
import Utils as Utils
import WorkQueue as WorkQueue
import PyUtilModule.WorkingSet as WorkingSet
import PyUtilModule.WorkingSetManager as WorkingSetManager
from typing import Set, Tuple
